clear all % Clear all and delete all previous data
close all

tic

p            = LoadPath()                                                  ;

%%
R_values     = [0, 1, 2, 5, 6.5]                                           ; % Relaxation values 
tau          = 0:0.01:2.5                                                  ; % Tau in seconds
sz           = size(tau)                                                   ; % size of tau
percentage   = 10/100                                                      ; % percentage of noise 
noise        = ((rand(sz) - 0.5) / 0.5) * percentage                       ;

% Create a subplot with R_values rows and 1 column
figure('Color', 'white','DefaultAxesFontSize',20,'Position',[700 0 850 2000])                       ;


for i = 1:length(R_values)
        R = R_values(i)                                                    ;

        % Generate the noisy signal with different relaxation values
        y                 = sin(2 * pi * tau) .* exp(-2*R*tau)             ;
        ynorm             = y / max(y)                                     ;

        ynoise            = ynorm + noise                                  ; 

        % Fitting
        initial_params    = [1, 1, 1]                                      ;
        fitting_function  = @(params, x) SinusDamp(params(1), params(2), params(3), x)  ;
        [beta1,R,J,CovB]  = nlinfit(tau, ynoise, fitting_function, initial_params)      ;
        ysim              = fitting_function(beta1, tau)                   ;
        SE                = sqrt(diag(CovB))                               ;

        J1                = beta1(2)                                       ;
        R1                = beta1(3)                                       ;
        
        % Plot the noisy signal in the subplot
        subplot(length(R_values), 1, i)                                    ;
        plot(tau, ynoise, 'o', tau, ysim, 'LineWidth', 3)                  ;
        yline(0)                                                           ;
        axis([-0.1, 3, -1.1, 1.1])                                         ;
    %    title(['Fitted Values (R = ' num2str(R1) ', J = ' num2str(J1) ')'])    ;
        title(sprintf("Fitted Values: R = %.3f ± %.3f s-1 & J = %.3f ± %.3f Hz",R1,SE(3),J1,SE(2)))
        xlabel('𝜏_2 (s)','Fontsize',22)                                    ;
        ylabel('Signal (norm.)')                                           ;
        legend('Noisy Signal', 'Fitted Signal')                            ;
        legend('boxoff')

end
toc

