clear all
close all 
tic
p = LoadPath()                                                             ;


%%
%%%%%%%%%% Load all data and conbine them %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Folder         = "P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230822_1_13C_Pyr_4\Adjusted\"   ;

Files{1}       = "20230822_1_13C_Pyr_4_exp20_(1)_29.1_256K_adjusted.csv"  ;
Files{2}       = "20230822_1_13C_Pyr_4_exp206_(1)_29.1_258K_adjusted.csv" ;
Files{3}       = "20230822_1_13C_Pyr_4_exp306_(1)_29.1_261K_adjusted.csv" ;
Files{4}       = "20230822_1_13C_Pyr_4_exp22_(1)_27.2_256K_adjusted.csv"  ;
Files{5}       = "20230822_1_13C_Pyr_4_exp208_(1)_27.2_258K_adjusted.csv" ;
Files{6}       = "20230822_1_13C_Pyr_4_exp308_(1)_27.2_261K_adjusted.csv" ;

[xdata,ydata]  = combinealldata(Folder,Files)                              ;
xdata          = xdata/1e3                                                 ;
%%
%%%%%%%%%%%%%% Fitting all combined data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial parameter guesses
initial_params = [5,   5, 5, ...
                  4,   5, 5, ...
                  1, 0.7,    ...
                  3,   4, 5      ]                                         ;

%%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function = @(params, x) Fit_CA_6_SEPP_SPINEPT(params(1), params(2) , params(3) , ...
                                                      params(4), params(5) , params(6) , ...
                                                      params(7), params(8) , ...
                                                      params(9), params(10), params(11), x)   ;

%%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB] = nlinfit(xdata, ydata, fitting_function, initial_params) ;

ysim             = fitting_function(beta1,xdata)                           ;
SE               = sqrt(diag(CovB))                                        ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
J1               = beta1(7)                                                ;
J2               = beta1(8)                                                ;
R1               = beta1(9)                                                ;
R2               = beta1(10)                                               ;
R3               = beta1(11)                                               ;

disp('Fitted Parameters:')                                                 ;
fprintf('J1 = %.3f ± %.3f Hz \n\r',[J1,SE(7)])                             ;
fprintf('J2 = %.3f ± %.3f Hz \n\r',[J2,SE(8)])                             ;
fprintf('R1 = %.3f ± %.3f Hz \n\r',[R1,SE(9)])                             ;
fprintf('R2 = %.3f ± %.3f Hz \n\r',[R2,SE(10)])                            ;
fprintf('R3 = %.3f ± %.3f Hz \n\r',[R3,SE(11)])                            ;

%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
plotNkinetics_loc(6,xdata,ydata,xdata,ysim)                                ;


toc
%%
%%%%%%%%%%%%%%%%%%Functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [xdata, ydata] = combinealldata(Folder,Files) 

loaddata  = load(Folder+Files{1})                                          ;
xdata     = loaddata(:,1)                                                  ;
ydata1    = loaddata(:,2)                                                  ;
loaddata  = load(Folder+Files{2})                                          ;
ydata2    = loaddata(:,2)                                                  ;
loaddata  = load(Folder+Files{3})                                          ;
ydata3    = loaddata(:,2)                                                  ;
loaddata  = load(Folder+Files{4})                                          ;
ydata4    = loaddata(:,2)                                                  ;
loaddata  = load(Folder+Files{5})                                          ;
ydata5    = loaddata(:,2)                                                  ;
loaddata  = load(Folder+Files{6})                                          ;
ydata6    = loaddata(:,2)                                                  ;

ydata     = [ydata1', ydata2', ydata3',ydata4', ydata5', ydata6']'         ;
end
%%

function RMSD = plotNkinetics_loc(N,x,y,xsim,ysim)
            y = reshape(y,length(x),N)                                     ;
         ysim = reshape(ysim,length(x),N)                                  ;
         figure("Color","white")
    
    for k=1:N
        subplot(N,1,k)                                                     ;
        plot(x,y(:,k),"LineWidth",2,"Marker","o")
        hold on
        plot(xsim,ysim(:,k),"LineWidth",2,"Marker","o")                    ;
        hold off
    
        xlabel("𝜏_2 (s)")
        ylabel("Integrals (norm.)")
        axis([0,x(end)+0.2,-0.1,1.1])
        RMSD = rms(y(:,k)-ysim(:,k))                                       ;
        legend({"exp","sim"})
        title(sprintf("RMSD = %.4f",RMSD))                                 ;
    end
end