clear all
close all 
tic
p = LoadPath()                                                             ;


%%
%%%%%%%%%% Load all data and conbine them %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Folder         = "P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230907_1_13C_Pyr_6\Adjusted\"   ;

% Files{1}       = "20230907_1_13C_pyr_6_exp20_-29.1_(1)_256K_adjusted.csv"  ;
% Files{2}       = "20230907_1_13C_pyr_6_exp120_-29.1_(1)_261K_adjusted.csv" ;
% Files{3}       = "20230907_1_13C_pyr_6_exp220_-29.1_(1)_267K_adjusted.csv" ;
% Files{4}       = "20230907_1_13C_pyr_6_exp22_-27.2_(1)_256K_adjusted.csv"  ;
% Files{5}       = "20230907_1_13C_pyr_6_exp122_-27.2_(1)_261K_adjusted.csv" ;
% Files{6}       = "20230907_1_13C_pyr_6_exp222_-27.2_(1)_267K_adjusted.csv" ;

Files{1}       = "20230907_1_13C_pyr_6_exp26_-14.98_(2)_256K_adjusted.csv" ;
Files{2}       = "20230907_1_13C_pyr_6_exp126_-14.98_(2)_261K_adjusted.csv";
Files{3}       = "20230907_1_13C_pyr_6_exp226_-14.98_(2)_267K_adjusted.csv";
Files{4}       = "20230907_1_13C_pyr_6_exp24_-24.09_(2)_256K_adjusted.csv" ;
Files{5}       = "20230907_1_13C_pyr_6_exp124_-24.09_(2)_261K_adjusted.csv";
Files{6}       = "20230907_1_13C_pyr_6_exp224_-24.09_(2)_267K_adjusted.csv";



[xdata,ydata, data_lengths]  = combinealldata(Folder,Files)                ;
xdata                        = xdata/1e3                                   ;
%%
%%%%%%%%%%%%%% Fitting all combined data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial parameter guesses
initial_params = [5,   5, 5, ...
                  4,   5, 5, ...
                  1, 0.7, ...
                  3,   4, 5]                                               ;

%%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function = @(params, x) Fit_CA_6_SEPP_SPINEPT_nonuniform(params(1), params(2), params(3), ...
                                                      params(4), params(5), params(6), ...
                                                      params(7), params(8), ...
                                                      params(9), params(10), params(11),data_lengths, x);

%%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB] = nlinfit(xdata, ydata, fitting_function, initial_params) ;

ysim             = fitting_function(beta1,xdata)                           ;
SE               = sqrt(diag(CovB))                                        ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
J1               = beta1(7)                                                ;
J2               = beta1(8)                                                ;
R1               = beta1(9)                                                ;
R2               = beta1(10)                                               ;
R3               = beta1(11)                                               ;

disp('Fitted Parameters:')                                                 ;
fprintf('J1 = %.3f ± %.3f Hz \n\r',[J1,SE(7)])                             ;
fprintf('J2 = %.3f ± %.3f Hz \n\r',[J2,SE(8)])                             ;
fprintf('R1 = %.3f ± %.3f Hz \n\r',[R1,SE(9)])                             ;
fprintf('R2 = %.3f ± %.3f Hz \n\r',[R2,SE(10)])                            ;
fprintf('R3 = %.3f ± %.3f Hz \n\r',[R3,SE(11)])                            ;

%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
plotNkinetics_loc(6,xdata,ydata,xdata,ysim,data_lengths)                   ;

%saveas(gcf,'P:\user_permanent\Charbel_Assaf\0_NMR_Data\1_NMR400\20230907_1_13C_Pyr_6\Adjusted\1-13C_[2].png')
toc
%%
%%%%%%%%%%%%%%%%%%Functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [xdata, ydata, data_lengths] = combinealldata(Folder, Files)
                            num_files = length(Files)                      ;

                            xdata     = []                                 ;
                            ydata     = []                                 ;
                         data_lengths = zeros(1, num_files)                ;

    for i = 1: num_files
        loaddata        = load(fullfile(Folder, Files{i}))                 ;
        xdata           = [xdata, loaddata(:, 1)']                         ;                
        ydata           = [ydata, loaddata(:, 2)']                         ;
        data_lengths(i) = length(loaddata(:, 1))                           ;
    end

    xdata = xdata'                                                         ;
    ydata = ydata'                                                         ;
end

function RMSD  = plotNkinetics_loc(N,x,y,xsim,ysim,L)
                               
    figure("Color","white",'DefaultAxesFontSize',20,'Position',[700 0 850 1700])
    c = 0                                                                  ;
    for k = 1:N
        subplot(N,1,k)
        plot(x(c+1:c+L(k)),y((c+1:c+L(k))),"LineWidth",2,"Marker","o")
        hold on
        plot(xsim(c+1:c+L(k)),ysim((c+1:c+L(k))),"LineWidth",2,"Marker","o") ;
        hold off
        
%        xlabel("𝜏_2 (s)",'Fontsize',12)
%        ylabel("Integrals (norm.)")
        axis([-0.1,max(x)+0.2,-0.4,1.1])
        RMSD = rms(y((c+1:c+L(k)))-ysim((c+1:c+L(k))))                     ;
        legend({"Experimental","Fitting"})
        legend('boxoff')
%        title(sprintf("RMSD = %.4f",RMSD))                                ;
        c = c + L(k)                                                       ;
    end
end