%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p=LoadPath();
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System=Load_SABRE_System_Name(5);
ex=Load_SABRE_System(System);

ex.Folder="out\SABRESHEATH_"+System+"_tb.mat";
%% kinetic parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.fpH=1;                   % pH2 fraction (1 - 100)%
%ex.Kd =10;                 % [s^-1] dissociation rate for MOD2
%ex.Wa =ex.Kd/20;           % [s^-1] association rate for MOD2
ex.Kd = 30;                   % [s^-1] dissociation rate for exC
ex.tv=linspace(0,120,20);   % delay/storage external magnetic field, T
%% magnetic fields %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.Bv=3.2*1e-7;   % delay/storage external magnetic field, T
%% rhos for exC SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.Yout = sabre_exC_tB(ex);
% plot
figure("Color","white")
plot(ex.tv,ex.Yout.c{ex.show_c(1)}*100,'b',"LineWidth",2);
hold on
plot(ex.tv,ex.Yout.c{ex.show_c(2)}*100,'r',"LineWidth",2);
plot(ex.tv,ex.Yout.c{ex.show_c(3)}*100,'g',"LineWidth",2);
legend(ex.SOcStr(ex.show_c(1:3)));
xlabel("time SABRE SHEATH (s)");
ylabel("Polarization (%)");
title("SABRE SHEATH with tb = "+num2str(ex.Bv*1e9,3)+"nT, free substrate");


%% rhos for exC SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ex.Yout = sabre_MOD2_tB(ex);
% % plot
% figure("Color","white")
% plot(ex.tv,ex.Yout.s{ex.show_s(1)}*100,'b',"LineWidth",2);
% hold on
% plot(ex.tv,ex.Yout.s{ex.show_s(2)}*100,'r',"LineWidth",2);
% plot(ex.tv,ex.Yout.s{ex.show_s(3)}*100,'g',"LineWidth",2);
% legend(ex.SOsStr(ex.show_s(1:3)));
% xlabel("time SABRE SHEATH (s)");
% ylabel("Polarization (%)");
% title("SABRE SHEATH at "+num2str(ex.Bv*1e9,3)+"nT, free substrate");
% display("[Substrate]/[Catalyst] = "+num2str(ex.Yout.SABRE.fs/ex.Yout.SABRE.fc));
% %%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% save data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
save(ex.Folder,"ex");


%% fit C in free
x=ex.tv';
y = ex.Yout.c{ex.show_c(3)};
figure('Color','white','Units',"pixels",'Position', [10 100 600 700])
plot(x,y*100,"LineWidth",1.5);
       
ax = gca; 
ax.set('FontSize',12,'FontName','Arial');        
title(sprintf(System+"("+"C free"+")"+' '+ex.SOsStr{ex.show_c(1)}+', k_d''=%.2f s^-^1',[ex.Kd]),'FontSize',10,'FontName','Arial');
xlabel('time SLIC PULSE (s)','FontSize',12,'FontName','Arial');
ylabel('Polarization (%)'    ,'FontSize',12,'FontName','Arial');

A0=y(end);
B0=y(1)-y(end);
T0=-x(round(end/2))/log((y(round(end/2))-y(end))/(y(1)-y(end)));
opt=fitoptions('Method','NonLinearLeastSquare',...
                    'StartPoint',[A0,B0,T0],...
                     'Lower',[-Inf,-Inf,0],...
                    'Upper',[Inf,Inf,100],...
                    'MaxIter',1e6);
myexp=fittype('A+B*exp(-x/T)','options',opt); %this line define fitting function
[result gof]=fit(x,y,myexp);%goodness-of-fit statistics to the structure gof
coef=coeffvalues(result); %extracting coefficients 
int=confint(result); % extracting trusting interval for 95% confidence =2sigma
meanerror=abs((int(2,:)-int(1,:))/2);

leg= {"B0="+num2str(ex.Bv*1e6,3)+" uT";
      "T ="+num2str(result.T)+" s"}; 
hold on
plot(x,result(x)*100,'r')
hold off
legend(leg,'FontSize',12,'FontName','Arial');
result


toc
