% here is an example of simulations of 1D NMR spectrum using Bloch class
% 90y - FID

clear all
close all 
tic 
p               = LoadPath()                                               ;
%%
% System parameters
Spec.System     = SPINS_Systems(4)                                         ; % 1 = A, 2 = AB, 3 = ABC, 4 = CsS2->S2
[Spec.T1,Spec.T2,Spec.C,Spec.wz,Spec.K]  = Load_SPINS_Systems(Spec.System) ;

% Declaration of spins
Spec.M          = SPINS(Spec.T1,Spec.T2,Spec.C)                            ; 
Spec.time2relax = 1000                                                     ; % This is to let system to reach steady state
Spec.time_mix   = linspace(0,8,40)'                                        ; % Time in second [s]

% sepctral parameters
Spec.lb         = 2                                                        ; % Linebroadening [Hz]
Spec.sw         = 2000                                                     ; % Sampling frequency                    
Spec.td         = 2^13                                                     ; % Length of signal
Spec.si         = Spec.td*4                                                ; % Length of signal after zerofilling

Spec.d1         = 1000                                                     ; % Time before acquisition time [s]
Spec.d14        = 0.000020885                                              ; % Time for evolution after shaped pulse [s] 0.002885
Spec.selective_excitation = 1                                              ; % Excite with selective excitation spin 1
Spec.o1                   = Spec.wz(Spec.selective_excitation)             ; % rotating frame of reference during SOT
Spec.Integral_width       = 40                                             ; % Hz this is the integration width
Spec.ds                   = 8                                              ; % Dummy scans
Spec.ns                   = 8                                              ; % values between 1 and 16 for phase cycling
Spec.ph0                  = -90                                            ;
Spec.Integrals_range = Spec.wz'*[1,1]/(2*pi)+[-1,1]*Spec.Integral_width/2  ;

%% Simulation of SEXY:selno experiment with phase cycling

Spec                      = Spec.M. selno_PC(Spec)                         ; % Calculate SEXSY:selno sequence with phase cycling

%%
Spec                      = Spec.M.proc_all_1D(Spec)                       ; % calculate spectrum
Spec.M. Plot_Spectra(Spec)                                                 ; % Plot spectra of sexy experiment

% plot Sexy integrals
figure("color","white")
plot(Spec.time_mix,Spec.Integrals,"o")                                     ;
Spec.Legends    = {"Bound","Free","3","4","5"}                             ;
legend(Spec.Legends{1:Spec.M.N})
ylabel("Integral (norm.)")
xlabel("Time mix (s)")

toc
%% save SEXY integrals
% % save integrals
 out = [Spec.time_mix,real(Spec.Integrals)]                                       ;
% save("SEXY_mixingtime_integrals.txt","out","-ASCII")                       ;
% % save normolised integrals on max value
% out = [Spec.time_mix,Spec.Integrals/max(max(abs(Spec.Integrals)))]         ;
% save("SEXY_mixingtime_normintegrals.txt","out","-ASCII")                   ;
% % save ranges of integrals
% out = [Spec.Integrals_range]                                               ;
% save("SEXY_integrals_ranges_Hz.txt","out","-ASCII")                        ;
% % save all SEXY parameters
% save("SEXY_experiment","Spec")

% PAPER = [real(Spec.Proc.Spectrum{1})',real(Spec.Proc.Spectrum{10})',real(Spec.Proc.Spectrum{20})',real(Spec.Proc.Spectrum{30})',real(Spec.Proc.Spectrum{40})'];