clear all
close all 
tic
p = LoadPath('CA')                                                         ;


%%
%%%%%%%%%%%%%%%%%%%%%% Load all data  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
n             = 'kd_pyr_pyr_64mM_[1]'                                     ; % _100mM                                                                              
File          = "IrHH_data\kd_pyr_pyr_[1]\"                               ; %  
data_in       = load(File + n + '.txt','-ASCII')                           ;
data.dmix0    = data_in(:,1)                                               ;
data.dmix     = data.dmix0-data.dmix0(1)                                   ; % Here we take in consideration that first point starts from 0 and all dmix are adjusted
data.C1       = data_in(:,2)                                               ; % Integrals of excited carbon   
data.Cf       = data_in(:,3)                                               ; % Integrals of free carbon  
data.C2       = data_in(:,4)                                               ; % Integrals of exchangeable carbon 

%%
% Choosing the fitting Model 

Model_types{1} = '13C2-[1]↔13C2-[2]↔13C2-free'                           ;
Model_types{2} = '13C2-[1]↔13C2-[2]↔13C2-free_alpha'                     ; % with correction of second set to enhance fitting

Model_type     = Model_types  {2}                                          ; % choose the Fitting Model

            
switch Model_type
         
       case '13C2-[1]↔13C2-[2]↔13C2-free'      
           
            fprintf("start to fit with 13C2-[1]↔13C2-[2]↔13C2-free Matrix model \n")
            MC1 = 1;                  MC2 =  data.C2(1)                 ;   MCf = data.Cf(1) ; alpha = 1    ; RF = 1/30.27           ;
            data.r                        = zeros(size(data.dmix))                                                                   ; %     
            Nt                            = length(data.dmix)                                                                        ;
            xdata_fit                     = reshape(data.dmix*[1,1,1],3*Nt,1)                                                        ;
            ydata                         = [data.C1; data.C2; data.Cf ]                                                             ; % the three sets of ydata values
            I                             = [ 0.018, 0.168, 0.002, 0.003,0.045,0.546,0.051,0.3,0.1]                                  ; % kd1, kd2, kaprime1, kaprime2, kex1, kex2,R1, R2 ,Rf
            
            % Initial guess                                                         MC1, MC2, MCF, kd1, kd2, kaprime1, kaprime2, kex1, kex2,R1, R2 ,Rf,x
            fitfunc                       = @(I, x)SABRE_carbon_exchange_Lmatrix_3R(MC1, MC2, MCf, I(1), I(2), I(3), I(4), I(5),I(6), I(7), I(8), RF, x)             ;
            y0                            = SABRE_carbon_exchange_Lmatrix_3R(MC1, MC2, MCf, I(1), I(2), I(3), I(4), I(5), I(6), I(7), I(8), RF, xdata_fit )          ;
            semilogx(data.dmix, data.C1, 'o', data.dmix, data.C2, 'o',data.dmix, data.Cf, 'o',data.dmix,reshape(y0,Nt,3))            ;   
            title("initial guess")
            [beta1,R,J,CovB]              = nlinfit(xdata_fit,ydata,fitfunc, I)                                                      ;
            SE                            = sqrt(diag(CovB))                                                                         ;
            
       case '13C2-[1]↔13C2-[2]↔13C2-free_alpha'
           
            fprintf("start to fit with 13C2-[1]↔13C2-[2]↔13C2-free Matrix_alpha model \n")
            MC1 = 1;                  MC2 =  data.C2(1)                 ;   MCf = data.Cf(1)   ; alpha = 2  ;RF = 1/30.27            ; 
            data.r                        = zeros(size(data.dmix))                                                                   ; %     
            Nt                            = length(data.dmix)                                                                        ;
            xdata_fit                     = reshape(data.dmix*[1,1,1],3*Nt,1)                                                        ;
            ydata                         = [data.C1; data.C2*alpha; data.Cf ]                                                       ; % the three sets of ydata values
            I                             = [ 0.018, 0.168, 0.002, 0.003,0.045,0.546,0.051,0.3,0.1]                                  ; % kd1, kd2, kaprime1, kaprime2, kex1, kex2,R1, R2 ,Rf
            
            % Initial guess                                                         MC1, MC2, MCF, kd1, kd2, kaprime1, kaprime2, kex1, kex2,R1, R2 ,Rf,x
            fitfunc                       = @(I, x)SABRE_carbon_exchange_Lmatrix_3R_alpha(MC1, MC2, MCf, I(1), I(2), I(3), I(4), I(5),I(6), I(7), I(8), RF, x,alpha)             ;
            y0                            = SABRE_carbon_exchange_Lmatrix_3R_alpha(MC1, MC2, MCf, I(1), I(2), I(3), I(4), I(5), I(6), I(7), I(8), RF, xdata_fit,alpha )          ;
            semilogx(data.dmix, data.C1, 'o', data.dmix, data.C2, 'o',data.dmix, data.Cf, 'o',data.dmix,reshape(y0,Nt,3))            ;   
            title("initial guess")
            [beta1,R,J,CovB]              = nlinfit(xdata_fit,ydata,fitfunc, I)                                                      ;
            SE                            = sqrt(diag(CovB))               ;
            
end


%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%

kd1                           = beta1(1)                                   ;
kd2                           = beta1(2)                                   ; 
kaprime1                      = beta1(3)                                   ;
kaprime2                      = beta1(4)                                   ;
kex1                          = beta1(5)                                   ; 
kex2                          = beta1(6)                                   ; 
R1                            = beta1(7)                                   ;
R2                            = beta1(8)                                   ; 
%RF                            = beta1(9)                                   ;

disp('Fitted Parameters:')                                                 ;
fprintf('kd1  = %.3f ± %.3f s^-1 \n\r',[kd1,SE(1)])                        ;
fprintf('kd2  = %.3f ± %.3f s^-1 \n\r',[kd2,SE(2)])                        ;
fprintf('kaprime1 = %.3f ± %.3f s^-1 \n\r',[kaprime1,SE(3)])               ;
fprintf('kaprime2 = %.3f ± %.3f s^-1 \n\r',[kaprime2,SE(4)])               ;
fprintf('kex1 = %.3f ± %.3f s^-1 \n\r',[kex1,SE(5)])                       ;
fprintf('kex2 = %.3f ± %.3f s^-1 \n\r',[kex2,SE(6)])                       ;
fprintf('R1 = %.3f ± %.3f s^-1 \n\r',[R1,SE(7)])                           ;
fprintf('R2 = %.3f ± %.3f s^-1 \n\r',[R2,SE(8)])                           ;
fprintf('RF = %.3f ± %.3f s^-1 \n\r',[RF,SE(9)])                           ;
            
figure("Color","white",'DefaultAxesFontSize',20,'Position',[1500 500 850 800])                                          ;
semilogx(data.dmix0, data.C1, 'oblack', data.dmix0, data.C2, 'or',data.dmix0, data.Cf, 'ob')                            ;
hold on                                                                                                                 ;
x_fit                     = logspace(log10(min(data.dmix0)),log10(max(data.dmix0)),100)'                                ;
x_fit_fit                 = reshape(x_fit*[1,1,1],3*length(x_fit),1)                                                    ;
y_fit                     = fitfunc(beta1,x_fit_fit)                                                                    ;
semilogx(x_fit, y_fit(1:100), 'black',x_fit, y_fit(101:200)/alpha, 'red',x_fit, y_fit(201:end), 'blue')                 ;
ylim([-0.1 1.1])                                                                                                        ;
xlim([data.dmix(1) data.dmix(end)])
legend('Ha', 'Hb', 'H2','Fitting')                                                                                      ;
PAPER                     = [ x_fit, y_fit(1:100), y_fit(201:end),y_fit(101:200)]                                       ;
%PAPER                    = [x_fit, y_fit(1:100), y_fit(101:200),y_fit(201:end)]                                        ;
%csvwrite(File+'_simdata_'+ Model_type +'.csv',PAPER) 

                        
toc
