clear all
close all 
tic
p = LoadPath('CA')                                                         ;


%%
%%%%%%%%%%%%%%%%%%%%%% Load all data  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Folder         = "IrHH_data\kd_IrHH_pressure_[1]\"                         ;

Files{1}       = "kd_IrHH_Ha_press_100PSI_[1].txt"                       ;
Files{2}       = "kd_IrHH_Hb_press_100PSI_[1].txt"                        ;

[x,y, L]       = combinealldata(Folder,Files)                              ;

% Initial parameter guesses
I              = [1,   1, 0.04, 1 ]                                           ;
Rf             = 1/1.93                                                    ; % 1.94  1.93  1.88  1.898  1.821           
%% %%%%%%%%%%%% Fitting all combined data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

MHa  = y(cumsum([1,3*L(1)]))                                               ;   
MHb  = y(cumsum([L(1)+1,2*L(1)+L(2)]))                                     ;  
MH2  = y(cumsum([2*L(1)+1,L(1)+2*L(2)]))                                   ;
        
       %                                                  (MHa1, MHb1,   MH2, RH2,kd,kex,kaprime,RIrHH,L, x)
fitting_function = @(I, x) Fit_CA_2_SEPP_SABRE_nonuniform( MHa,   MHb,   MH2, Rf,     ...
                                                                 I(1),      I(2),     ...
                                                                 I(3),      I(4),     ...
                                                                 L, x); % (MHa1,MHb1,MH21,MHa2,MHb2,MH22,RH2,kd,kex,kaprime,RIrHH,L, x)           
           
    
%% %%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB]  = nlinfit(x, y, fitting_function, I)                     ;

ysim              = fitting_function(beta1,x)                              ;
SE                = sqrt(diag(CovB))                                       ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
kd                = beta1(1)                                               ;
kex               = beta1(2)                                               ;
kaprime           = beta1(3)                                               ;
RIrHH             = beta1(4)                                               ;


disp('Fitted Parameters:')                                                 ;
fprintf('kd  = %.3f ± %.3f s^-1 \n\r',[kd,SE(1)])                          ;
fprintf('kex = %.3f ± %.3f s^-1 \n\r',[kex,SE(2)])                         ;
fprintf('kaprime = %.3f ± %.3f s^-1 \n\r',[kaprime,SE(3)])                 ;
fprintf('RIrHH = %.3f ± %.3f s^-1 \n\r',[RIrHH,SE(4)])                     ;

%% %%%%%%%%%% Increasing the number of the fitting points %%%%%%%%%%%%%%%%%%

x_fit           = logspace(log10(0.5*min(x)),log10(max(x)*2),100)'         ;
x_fit2          = reshape(x_fit*[1,1],2*length(x_fit),1)                   ;
L2              = length(x_fit)*[1,1]                                      ;                                             

fitting_function2  = @(I, x) Fit_CA_2_SEPP_SABRE_nonuniform ( MHa, MHb,   MH2,        Rf,     ...
                                                                         I(1),      I(2),     ...
                                                                         I(3),      I(4),     ...
                                                                           L2,       x_fit2)      ; % (MHa1,MHb1,MH21,MHa2,MHb2,MH22,kd,kex,kaprime,RHa,RHb,RH2,L, x)  

y_fit              = fitting_function2(beta1,x_fit2)                       ; 
                                           
                                             
%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
plotNkinetics_loc(2,x,y,x_fit,y_fit,L,L2)                                  ; 

toc
%%
%%%%%%%%%%%%%%%%%%Functions%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [xdata, ydata, data_lengths] = combinealldata(Folder, Files)
                            num_files = length(Files)                      ;

                            xdata     = []                                 ;
                            ydata     = []                                 ;
                         data_lengths = zeros(1, num_files)                ;

    for i = 1: num_files
        loaddata        = load(fullfile(Folder, Files{i}))                 ;
        xdata           = [xdata, loaddata(:, 1)']                         ;                
        ydata           = [ydata, loaddata(:, 2)',loaddata(:, 3)',loaddata(:, 4)'] ;
        data_lengths(i) = length(loaddata(:, 1))                           ;
    end

    xdata = xdata'                                                         ;
    ydata = ydata'                                                         ;
end

function RMSD  = plotNkinetics_loc(N,x,y,xsim,ysim,L,L_fit)
                               
    figure("Color","white",'DefaultAxesFontSize',20,'Position',[700 0 850 800])
    start          = 1                                                     ; 
    startx         = 1                                                     ;
    start_fit      = 1                                                     ; 
    startx_fit     = 1                                                     ;
    colors         = [0 0 0 ;0.5 0.5 0.5; 1 0 0]                           ; 
    markers        = {'s', 'hexagram', 'O'}                                ; % Define markers
    c = 0                                                                  ;
    for k = 1:N
        subplot(N,1,k)
        h = semilogx(x(startx:startx-1+L(k))',reshape(y(start:start+3*L(k)-1),L(k),3),'MarkerSize',13,'LineStyle', 'none', 'LineWidth',2);
        colororder(colors)
        set(h, {'Marker'}, markers(:))                                     ; % Apply markers to each line
        set(gca,'linewidth',2,'Fontsize',26)                               ;
        hold on
        semilogx(xsim,reshape(ysim(start_fit:start_fit+3*L_fit(k)-1),L_fit(k),3), "LineWidth",2) ;
         
        start      = start  + 3*L(k)                                       ;        
        startx     = startx + L(k)                                         ;
        start_fit  = start_fit + 3*L_fit(k)                                ;
        
        hold off
        legend(["[3]^a","[3]^b","H_2"],'Fontsize',32)                      
        % xlabel("𝜏_e (s)",'Fontsize',22)
        % ylabel("Integrals (norm.)")

        xticks([ 0.001 0.01 0.1 1 10])
        xticklabels({ '0.001', '0.01', '0.1', '1', '10'})
        yticks([ 0 0.2 0.4 0.6 0.8 1])
        yticklabels({'0', '0.2', '0.4', '0.6', '0.8', '1'})
        axis([0.001,max(x)+20,-0.2,1.1])        
        legend('boxoff')
        c = c + L(k)                                                       ;
    end
    % saveas(gcf,'G:\.shortcut-targets-by-id\1sm8HgUXJdPnYH1dZK3HxYOaHt5pDZtFT\IrHH_exchange_paper_2024\Figure\Figure_S6.1_IrHH_pyr_[3]\pyr_174mM.png')
end