% 
clear all
close all 
tic
p = LoadPath('CA')                                                         ;

%%%%%%%%%%%%%%%%%%%%%% Load all data  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Folder         = "IrHH_data\"                                              ;

%%% complex [1] Ha and Hb 

Files{2}       = "kd_IrHH_DMSO_[1]\kd_IrHH_Ha_DMSO_75mM_[1].txt"          ; %  || kd_pyr_pressure_[1]\kd_pyr_press_75PSI_[1]_100mM   kd_IrHH_DMSO_[3]\kd_IrHH_Ha_DMSO_150mM_[3]_norm 2
Files{4}       = "kd_IrHH_DMSO_[1]\kd_IrHH_Hb_DMSO_75mM_[1].txt"          ; % kd_IrHH_DMSO_[3]\kd_IrHH_Hb_DMSO_150mM_[3]_norm.txt 4

%%% complex [2] Ha and Hb

Files{1}       = "kd_IrHH_DMSO_[2]\kd_IrHH_Ha_DMSO_75mM_[2].txt"          ; %  || kd_pyr_pressure_[1]\kd_pyr_press_75PSI_[1]_100mM   kd_IrHH_DMSO_[3]\kd_IrHH_Ha_DMSO_150mM_[3]_norm 1 
Files{3}       = "kd_IrHH_DMSO_[2]\kd_IrHH_Hb_DMSO_75mM_[2].txt"          ; % kd_IrHH_DMSO_[3]\kd_IrHH_Hb_DMSO_150mM_[3]_norm.txt 3

%%%  combine all data 

[x,   y, L]     = combinealldata(Folder,Files)                             ;
[x1, y1, L1]    = combinealldata1(Folder,Files)                            ;
%[x2, y2, L2]    = combinealldata2(Folder,Files)                           ;

%%%%%%%%%%%%%%%%%%%%  Fitting all combined data  %%%%%%%%%%%%%%%%%%%%%%%%%%

I = [   0.04,     0.4,       0.4, ...
       0.1,      0.1,     0.09, ...
          1   ]                                                            ; % Initial parameters k12, k21, kd1, kd2, kaprime1, kaprime2, Rin
      
%
MC1  = y(cumsum([1,3*L(1),3*L(2),3*L(3)]))                                 ;   
MC2  = y(cumsum([L(1)+1,2*L(1)+L(2),2*L(2)+L(3),2*L(3)+L(4)]))             ;  
MH2  = y(cumsum([2*L(1)+1,L(1)+2*L(2),L(2)+2*L(3),L(3)+2*L(4)]))           ;
Rf   = 1/1.93                                                              ;

% MC1 = [0,1,0,1];
% MC2 = [1,0,1,0];

    
%%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function = @(I, x) Fit_4_IrHH_C1_2( MC1, MC2, MH2,   Rf,     L,   ...  % 
                                                  I(1),    I(2),  I(3),   ...
                                                  I(4),    I(5),  I(6),   ...
                                                  I(7),    x)              ; % (MC1,  MC2, MH2, Rf, L,k12, k21, kd1, kd2, kaprime1, kaprime2, Rin, x)

%%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB] = nlinfit(x, y, fitting_function, I)                      ; % ydata_norm


x_fit              = logspace(log10(0.5*min(x)),log10(max(x)*2),100)'      ;
x_fit4             = reshape(x_fit*[1,1,1,1],4*length(x_fit),1)            ;
Lfit               = length(x_fit)*[1,1,1,1]                               ;
fitting_function2  = @(I, x) Fit_4_IrHH_C1_2( MC1, MC2, MH2, Rf, Lfit,   ...  % 
                                            I(1),    I(2),  I(3),   ...
                                            I(4),    I(5),  I(6),   ...
                                            I(7),    x)                    ; % (MHC1, MHC2, MH2, MHC12, MHC22, Rf, kd1, kaprime1, R1, kd2, k12, k21, kaprime12, kaprime22, Rin, L, x)
y_fit              = fitting_function2(beta1,x_fit4)                       ; 
ysim               = fitting_function(beta1,x)                             ;
SE                 = sqrt(diag(CovB))                                      ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
k12                = beta1(1)                                              ;
k21                = beta1(2)                                              ;
kd1                = beta1(3)                                              ;
kd2                = beta1(4)                                              ;
kaprime1           = beta1(5)                                              ;
kaprime2           = beta1(6)                                              ;
Rin                = beta1(7)                                              ;

disp('Fitted Parameters HH of complex [1] and [2] reduced:')               ;
fprintf('k12 = %.3f ± %.3f s^-1 ',[k12,SE(1)])                             ;
fprintf('k21 = %.3f ± %.3f s^-1 ',[k21,SE(2)])                             ;
fprintf('kd1  = %.3f ± %.3f s^-1 ',[kd1,SE(3)])                            ;
fprintf('kd2 = %.3f ± %.3f s^-1 ',[kd2,SE(4)])                             ;
fprintf('kaprime1  = %.3f ± %.3f s^-1 ',[kaprime1,SE(5)])                  ;
fprintf('kaprime2 = %.3f ± %.3f s^-1 ',[kaprime2,SE(6)])                   ;
fprintf('Rin = %.3f ± %.3f s^-1 \n\r',[Rin,SE(7)])                         ;

%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotNkinetics_loc(4,x,y,x_fit,y_fit,L,Lfit)                                ;


%% %%%%%%%%%%%%%%%%%%%%%%%% Step 2 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%% fitting complex [1] & [2] alone %%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%  Fitting all combined data  %%%%%%%%%%%%%%%%%%%%%%%%%%

I1 = [   0.4,     0.6,     0.8,   0.8   ]                                  ; % Initial parameters kex1,kex2,R1,R2
      
%
MC1Ha  = y1(cumsum([1,5*L1(1),5*L1(2),5*L1(3)]))                           ;   % c2ha  c1ha c2hb c1hb
MC1Hb  = y1(cumsum([L1(1)+1,4*L1(1)+L(2),4*L1(2)+L1(3),4*L1(3)+L(4)]))            ;  
MC2Ha  = y1(cumsum([2*L1(1)+1,3*L1(1)+2*L(2),3*L1(2)+2*L1(3),3*L1(3)+2*L1(4)]))   ;   
MC2Hb  = y1(cumsum([3*L1(1)+1,2*L1(1)+3*L(2),2*L1(2)+3*L1(3),2*L1(3)+3*L1(4)]))   ;  
MH2    = y1(cumsum([4*L1(1)+1,1*L1(1)+4*L(2),1*L1(2)+4*L1(3),1*L1(3)+4*L1(4)]))   ;
% MC1Ha  = [0,1,0,0];
% MC2Ha  = [1,0,0,0];  
%%%%%%%%%%%%%% Define the fitting function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function_Step2 = @(I1, x1) Fit_4_IrHH_C1_2_5data( MC1Ha, MC1Hb, MC2Ha, MC2Hb, MH2, Rf, L1, k12,    k21,  kd1,   ...  % MC1Ha, MC1Hb, MC2Ha, MC2Hb, MH2, Rf,L,k12,k21,kd1,kd2,kaprime1,kaprime2,kex1,kex2,R1,R2,
                                                            kd2,     kaprime1,  kaprime2,   ...
                                                          I1(1),        I1(2),     I1(3),   ...
                                                          I1(4),           x1);             % 

%%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%%%%
[beta2,R,J2,CovB2] = nlinfit(x1, y1, fitting_function_Step2, I1)           ; % ydata_norm


x_fit_2            = logspace(log10(0.5*min(x1)),log10(max(x1)*2),100)'    ;
x_fit2             = reshape(x_fit_2*[1,1,1,1],4*length(x_fit_2),1)        ;
Lfit_2             = length(x_fit_2)*[1,1,1,1]                             ;
fitting_function_Step2_1  =@(I1, x1) Fit_4_IrHH_C1_2_5data( MC1Ha, MC1Hb,  MC2Ha, MC2Hb, MH2, Rf, Lfit_2, k12,    k21,  kd1,   ...  % MC1Ha, MC1Hb, MC2Ha, MC2Hb, MH2, Rf,L,k12,k21,kd1,kd2,kaprime1,kaprime2,kex1,kex2,R1,R2,
                                                              kd2,      kaprime1,   kaprime2,   ...
                                                            I1(1),         I1(2),      I1(3),   ...
                                                            I1(4),           x1);             % 

y_fit_2            = fitting_function_Step2_1(beta2,x_fit2)                ; 
ysim_step2         = fitting_function_Step2(beta2,x1)                      ;
SE2                = sqrt(diag(CovB2))                                     ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
kex1                = beta2(1)                                             ;
kex2                = beta2(2)                                             ;
R1                  = beta2(3)                                             ;
R2                  = beta2(4)                                             ;


disp('Fitted Parameters HH of complex [1] and [2]:')                       ;
fprintf('kex1 = %.3f ± %.3f s^-1 ',[kex1,SE2(1)])                          ;
fprintf('kex2 = %.3f ± %.3f s^-1 ',[kex2,SE2(2)])                          ;
fprintf('R1   = %.3f ± %.3f s^-1 ',[R1,SE2(3)])                            ;
fprintf('R2   = %.3f ± %.3f s^-1 \n\r',[R2,SE2(4)])                        ;


%%%%%%%%%%%%%%%%%% Plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotNkinetics_loc1(4,x1,y1,x_fit_2,y_fit_2,L1,Lfit_2)                      ;


toc
% %% 
function [xdata, ydata, data_lengths] = combinealldata(Folder, Files)
                            num_files = length(Files)                      ;

                         xdata        = []                                 ;
                         ydata        = []                                 ;
                         data_lengths = zeros(1, num_files)                ;

    for i = 1: num_files

        loaddata        = load(fullfile(Folder, Files{i}))                 ;
        xdata           = [xdata, loaddata(:, 1)']                         ;   
        y               = [loaddata(:, 2)'+ loaddata(:, 3)',loaddata(:, 4)'+ loaddata(:, 5)',loaddata(:, 6)'];
        ynorm           = y/max(y)                                         ;
        ydata           = [ydata, ynorm]                                   ;  %[1] [2] H2
        data_lengths(i) = length(loaddata(:, 1))                           ;
  
    end

    xdata = xdata'                                                         ;
    ydata = ydata'                                                         ;
end

function [xdata, ydata, data_lengths] = combinealldata1(Folder, Files)
                            num_files = length(Files)                      ;

                         xdata        = []                                 ;
                         ydata        = []                                 ;
                         data_lengths = zeros(1, num_files)                ;

    for i = 1: num_files

        loaddata        = load(fullfile(Folder, Files{i}))                 ;
        xdata           = [xdata, loaddata(:, 1)']                         ;
        y               = [loaddata(:, 2)',loaddata(:, 3)',loaddata(:, 4)',loaddata(:, 5)',loaddata(:, 6)'];
        ynorm           = y/max(y)                                         ;
        ydata           = [ydata, ynorm]                                   ;  %[1] [2] H2
        data_lengths(i) = length(loaddata(:, 1))                           ;
   
    end

    xdata = xdata'                                                         ;
    ydata = ydata'                                                         ;
end


function RMSD  = plotNkinetics_loc(N,x,y,xsim,ysim,L,L_fit)
                               
    figure("Color","white",'DefaultAxesFontSize',22,'Position',[100 50 2200 1200]) % initial from left, initial from bottom, width, height
    start          = 1                                                     ; 
    startx         = 1                                                     ;
    start_fit      = 1                                                     ; 
    startx_fit     = 1                                                     ;
    colors         = [0.4660 0.6740 0.1880;0 0.4470 0.7410;1 0 0]          ; % g b r
    markers        = {'*', 'd', 'O'}                                       ; % Define markers
    
     sp            = [2,1,4,3]                                             ;
    for k = 1:N       
        subplot(N/2,N/2,sp(k))           
        
        h = semilogx(x(startx:startx-1+L(k))',reshape(y(start:start+3*L(k)-1),L(k),3),'MarkerSize',13,'LineStyle', 'none', 'LineWidth',2);  
        colororder(colors)
        set(h, {'Marker'}, markers(:))                                     ; % Apply markers to each line
        set(gca,'linewidth',3,'Fontsize',32)                               ;
        hold on
        semilogx(xsim,reshape(ysim(start_fit:start_fit+3*L_fit(k)-1),L_fit(k),3), "LineWidth",2) ;
        start      = start  + 3*L(k)                                       ;        
        startx     = startx + L(k)                                         ;
        
        start_fit  = start_fit + 3*L_fit(k)                                ;
        hold off
        legend(["[1]^a + [1]^b";"[2]^a + [2]^b";"H_2"],'Fontsize',32)      ;           
        %xlabel("𝜏_e (s)",'Fontsize',22)
        %ylabel("Integrals (norm.)")
        xticks([ 0.001 0.01 0.1 1 10])
        xticklabels({ '0.001', '0.01', '0.1', '1', '10'})
        yticks([ 0 0.2 0.4 0.6 0.8 1])
        yticklabels({'0', '0.2', '0.4', '0.6', '0.8', '1'})
        axis([0.001,max(x)+20,-0.15,1.15])        
        legend('boxoff')  
    end
    
  %  saveas(gcf,'G:\.shortcut-targets-by-id\1sm8HgUXJdPnYH1dZK3HxYOaHt5pDZtFT\IrHH_exchange_paper_2024\Figure\Figure_S5.0_IrHH_[DMSO]_[1]_[2]\DMSO_75mM_pre.png')
end

function RMSD  = plotNkinetics_loc1(N,x,y,xsim,ysim,L,L_fit)
                               
    figure("Color","white",'DefaultAxesFontSize',22,'Position',[100 50 2200 1200])
    start       = 1                                                        ; 
    startx      = 1                                                        ;
    start_fit   = 1                                                        ; 
    startx_fit  = 1                                                        ;
    colors      = [0.4660 0.6740 0.1880;0 1 0;0 0.4470 0.7410 ; 0 0 1; 1 0 0]; 
    markers     = {'+', 'X', '^', 'V', 'O'}                                ; % Define markers 
    sp          = [2,1,4,3]                                                ;
    for k = 1:N       
        subplot(N/2,N/2,sp(k))           
        
        h = semilogx(x(startx:startx-1+L(k))',reshape(y(start:start+5*L(k)-1),L(k),5),'MarkerSize',13,'LineStyle', 'none','LineWidth',2); % "Marker","o" 'defaultAxesLineStyleOrder','O|X|Δ|sqaure|diamond' ,'LineStyle', 'none'
        colororder(colors)
        set(h, {'Marker'}, markers(:))                                     ; % Apply markers to each line
        set(gca,'linewidth',3,'Fontsize',32)                               ;
        hold on
        semilogx(xsim,reshape(ysim(start_fit:start_fit+5*L_fit(k)-1),L_fit(k),5), "LineWidth",2) ;
        start   = start  + 5*L(k)                                          ;        
        startx  = startx + L(k)                                            ;
        
        start_fit = start_fit + 5*L_fit(k)                                 ;
        hold off
        legend(["[1]^a";"[1]^b";"[2]^a";"[2]^b";"H_2"],'Fontsize',32)      ;           
        %xlabel("𝜏_e (s)",'Fontsize',22)
        %ylabel("Integrals (norm.)")
        xticks([ 0.001 0.01 0.1 1 10])
        xticklabels({ '0.001', '0.01', '0.1', '1', '10'})
        yticks([ 0 0.2 0.4 0.6 0.8 1])
        yticklabels({'0', '0.2', '0.4', '0.6', '0.8', '1'})
        axis([0.001,max(x)+20,-0.15,1.15])        
        legend('boxoff')
        
    end
  %  saveas(gcf,'G:\.shortcut-targets-by-id\1sm8HgUXJdPnYH1dZK3HxYOaHt5pDZtFT\IrHH_exchange_paper_2024\Figure\Figure_S5.0_IrHH_[DMSO]_[1]_[2]\DMSO_75mM.png')
end