% Load values from .csv 
% Take certain value, fit them and then use the new values to normalize the
% spectrum 
% Line 28 : put the value of the repetitive tau 
clear all
close all 
tic
p = LoadPath();
%%%%%%%%
repetitivetau = 0.011    ; % Put the value of the repetitive tau (s)
%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%% Sequence %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System_type{1} = "HHN-1"     ;
System_type{2} = "HHNN-2"    ;
System_type{3} = "HHC-1"     ;
System_type{4} = "HHHC-1"    ;
System_type{5} = "HH-HHHC-1" ;

ESOTHERIC_types{1} = 'SABREESOTHERIC'                 ;
ESOTHERIC_types{2} = 'SABREESOTHERIC_2D_TA_TB'        ;
ESOTHERIC_types{3} = 'SABREESOTHERIC_2D_TA_vdList'    ;
ESOTHERIC_types{4} = 'SABREESOTHERIC_2D_TB_vdList'    ;
ESOTHERIC_types{5} = 'SABREESOTHERIC_TAvd_Multi_Kd'   ;
ESOTHERIC_types{6} = 'SABREESOTHERIC_TBvd_Multi_Kd'   ;
ESOTHERIC_types{7} = 'SABREESOTHERIC_tev'             ;
ESOTHERIC_types{8} = 'SABREESOTHERICtev_Multi_Kd'     ;

System             = System_type{2}                                                         ;
ESOTHERIC_type     = ESOTHERIC_types{5}                                                     ;  
ex.Folder          = "out\"+System+"\ESOTHERIC\"+ESOTHERIC_type+"\"+ESOTHERIC_type+"_"      ;  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% loading data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
ex.experiment = "expdata\"+System+"\ESOTHERIC\"+ESOTHERIC_type+"\"                     ; 
temp          = 293                                                                    ;
data_in       = load(ex.experiment+'SABRE_ESOTHERIC_'+temp+'K_original.csv','-ASCII')  ; 

data.tau      = data_in(:,1)                                ;
data.y        = data_in(:,2)                                ;

 
data.ID      = (0:length(data.tau)-1)'                      ;
data.norm    = data.y ./ max(data.y)                        ; % normalized by the maximum of the value 
data
%% plotting SABRE signal of the experiment in order of acquisition %%%%%%%%
figure;
set(gcf,'color','w')                    ;
plot(data.ID, data.y, 'x')              ;
xlabel('ID')                            ;
ylabel('Amplitude')                     ;
title('First signal')                   ;

% out = [data.ID, data.y];
% save("first signal.csv","out",'-ASCII')
%% plotting SABRE signal of the experiment %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure; 
set(gcf,'color','w')                    ;
subplot(2,2,1)                          ;
plot(1e3*data.tau, data.y, 'x')         ;
xlabel('Tau (ms)')                      ;
ylabel('Amplitude')                     ;
title('First signal')                   ;
grid on 

%% Having only values of the heighest signal %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
filter=data.tau==repetitivetau          ;  
cal.ID       = data.ID(filter)          ;
cal.y        = data.y(filter)           ;
cal.tau      = data.tau(filter)         ;
cal          = poly2_fit_cal(cal)       ;
cal.MeanMaxV = sum(cal.y(:,1))/length(cal.y); % mean amplitude of all repetitive tau
cal
%  plotting maximum amplitudes 
subplot(2,2,2)                          ;
plot(cal.ID, cal.y, 'x')                ;
xlabel('ID')                            ;
ylabel('Amplitude')                     ;
title(sprintf('Maximum Integrals (tau = %.3fms)',repetitivetau)); 
grid on 

% out = [cal.ID, cal.y];
% save("Max integrals.csv","out",'-ASCII')
%% fitting the maximum values %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data.corr    = poly2(cal.fit.constant,data.ID); % max value fitted for each tau
data.y_corr  = data.y ./ data.corr            ; % normalized by the max of the fitted value of each tau  %%%% ad the factor (1.17.*data.corr)

%% plotting normalized fitting maximum amplitudes %%%%%%%%%%%%%%%%%%%%%%%%%
subplot(2,2,3)                          ;
plot(1e3*data.tau, data.y_corr, 'x')    ;
xlabel('Tau (ms)')                      ;
ylabel('Amplitude')                     ;
title('Normalized after fitting');
grid on 

% plotting fitting + maximum amplitudes %%
subplot(2,2,4)                           ;
plot(data.ID,data.corr,'r','LineWidth',2);
hold on 
plot(cal.ID, cal.y,'O')                  ;
xlabel('ID')                             ;
ylabel('Max Amplitude')                  ;
title('fitting Max Integrals')           ;
grid on
% out = [data.ID, data.corr];
% save("fitting Max integrals.csv","out",'-ASCII')
%% All amplitude without the maximum %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
not=(data.tau~=repetitivetau)           ;
new.tau     = data.tau(not)             ;
new.ID      = data.ID(not)              ;
new.y       = data.y(not)               ;
new.norm    = data.norm(not)            ; % normalized by the maximum of the amplitudes 
new.fnorm   = data.y_corr(not)          ; % normalized by the fitted value of the maximum amplitudes of each tau

%% Insert the repetitive tau into new.tau %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
s = [new.tau,new.fnorm]                         ; % new.fnorm  new.y
cal.MeanMaxV = 1                                ; % cal.MeanMaxV/max(data.corr);%
s((end+1), :)= [repetitivetau ;cal.MeanMaxV ]   ;

[Sortedtau,I] = sort(s(:,1))                    ;
y = s(:,2)                                      ;
Sorted_f.norm = y(I)                            ;

%% plotting first results and adjusted results %%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure;
set(gcf,'color','w')                                 ;
subplot(1,2,1)                                       ; 
plot(1e3*data.tau, data.norm, 'O')                   ;
hold on
plot(1e3*data.tau, data.y_corr,'X')                  ; %data.y_corr
xlabel('Tau (ms)')                                   ;
ylabel('Amplitude')                                  ;
legend('Initial signal','signal after adjustment')   ;
grid on 

subplot(1,2,2)                                       ;
plot(1e3*new.tau, new.norm, 'r','LineWidth',2)       ;
hold on
plot(1e3*Sortedtau, Sorted_f.norm, 'b','LineWidth',2);
xlabel('Tau (ms)')                                   ;
ylabel('Amplitude')                                  ;
legend('Initial signal','signal after adjustment')   ;
grid on 

%% Plotting Max Integrals normalize by the fitting values %%%%%%%%%%%%%%%%%
figure;
cal.Maxfitted = data.y_corr(filter)            ;
plot(cal.ID, cal.Maxfitted, 'x')               ;
xlabel('ID')                                   ;
ylabel('Max Integral')                         ;
title('Max Integral Normalized after fitting') ;
hold on 
plot(new.ID, new.fnorm);
% out = [cal.ID, cal.Maxfitted];
% save("Max Integral Normalized after fitting.csv","out",'-ASCII')
% out = [new.ID, new.fnorm];
% save("Integrals after adjustment.csv","out",'-ASCII')
%% save data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
out = [Sortedtau, Sorted_f.norm] ;
save(ex.experiment+"\SABRE_ESOTHERIC_"+temp+"K_adjusted.csv","out",'-ASCII')
%%
toc