clear all
close all 
tic
p              = LoadPath('CA')                                                ;

%% Loading Experimental data 
%%% load experimental data 
%%% n is the reference of the data in the file 
n             = 34                                                   ; % Pyridine from 1,2,3,4   ACN 5,6,7,8    4AP 9,10,11,12,  NAM 13,14,15,16  MNZ 17,  18,  19,  20, 21  and the temperature for each one 280,283,288,293
data_params   = load("Experimental\Parameters.txt",'-ASCII')               ; %                                                                           262.5, 267, 270, 273, 278                              
data.K        = data_params(:,1)                                           ;

File          = "Experimental\";
data_in       = load(File + n + '.txt','-ASCII')                           ;
data.tau0     = data_in(:,1)                                               ;
data.tau      = data.tau0-data.tau0(1)                                     ; % Here we take in consideration that first point starts from 0 and all dmix are adjusted
data.ey       = data_in(:,2)                                               ; % Integrals of eq 
data.fy       = data_in(:,3)                                               ; % Integrals of free 



% Choosing the fitting Model 

Model_types{1} = 'CSS2↔CSS+S MatrixK'                                     ;
Model_types{2} = 'CSS2↔S2 MatrixK'                                        ;
Model_types{3} = 'Biexponential'                                           ;


Model_type     = Model_types  {1}                                          ; % choose the Fitting Model

            
switch Model_type
         
       case 'CSS2↔CSS+S MatrixK'      % for random Rf and Re 
            
            fprintf("start to fit with CSS2↔CSS+S MatrixK model \n")
            S0 = 400 ;   Ir0  = 4;       Mb = data.ey(1) ;   Mf = data.fy(1);   Mr = 0                                              ; % Initial constant guess  C = 1/8.01 
            K = data.K(n)                                                                                                            ;
            data.r                        = zeros(size(data.tau))                                                                    ; % Define third column zeros CsS     
            Nt                            = length(data.tau)                                                                         ;
            xdata_fit                     = reshape(data.tau*[1,1],2*Nt,1)                                                           ;
            ydata                         = [data.ey; data.fy]                                                                       ; % the two sets of ydata values
            initial_params                = [ 15.5, 0.02, 0.2, 0.2]                                                                      ; % kd ka Rb                  %%%%%
            
            % Initial guess                                                         (x,S0,Ir0,Mb, Mr, Mf, Rf, K,  kd,                    ka,            Rb)
            fitfunc                       = @(params, x)SABRE_twosite_exchange_LmatrixK(S0, Ir0, Mb, Mr, Mf, params(4), K, params(1), params(2),params(3),x )                                 ;
            y0                            = SABRE_twosite_exchange_LmatrixK(S0, Ir0, Mb, Mr, Mf, initial_params(4), K, initial_params(1), initial_params(2),initial_params(3),xdata_fit )     ;
            semilogx(data.tau, data.ey, 'o', data.tau, data.fy, 'o',data.tau,reshape(y0,Nt,2))                                       ;                                                                                                             
            title("initial guess")
            [beta1,R,J,CovB]              = nlinfit(xdata_fit,ydata,fitfunc, initial_params)                                         ;
            coefficients_standard_errors  = sqrt(diag(CovB))                                                                         ;
            CSE                           = coefficients_standard_errors                                                             ; 
            fprintf("results: \n")                                                                                                   ;
            fprintf("Model CSS2↔CSS+S MatrixK has kd = %.2f ± %.2f s-1,kaprime = %.2f ± %.2f s-1, Rb = %.2f ± %.2f s-1, Rf = %.2f ± %.2f s-1 \n",beta1(1),CSE(1),beta1(1)/K,CSE(1)/K,beta1(3),CSE(3),beta1(4),CSE(4))
            % Calculation of the concentrations after fitting for IrS, IrS2 and S
%             S                             = Substrate_concentration(beta1(3),beta1(3)/K,S0,Ir0)                                      ;
%             CsS2                          = S0-2*Ir0-S                                                                               ;
%             CsS                           = Ir0-CsS2                                                                                 ;
%             fprintf("[S0] = %.2f mM, [S] = %.2f mM, \n",S0, S)
%             fprintf("[Ir0] = %.2f mM, [IrS2] = %.2f  mM, [IrS] = %.2f ka = %.2f ± %.2f (s*mM)-1 \n",Ir0, CsS2, CsS,(beta1(3)/K)/CsS,(CSE(3)/K)/CsS )

            case 'CSS2↔S2 MatrixK'          % for random Rf and Re
            
            fprintf("start to fit with CSS2↔S2 MatrixK model \n")
            S0 = 400 ; Ir0 = 4;     Mb = data.ey(1);   Mf = data.fy(1)                                                               ; % Initial constant guess C = 1/3.535;
            K = data.K(n)                                                                                                           ;
            Nt                          = length(data.tau)                                                                          ;
            xdata_fit                   = reshape(data.tau*[1,1],2*Nt,1)                                                            ;
            ydata                       = [data.ey; data.fy]                                                                        ; % the two sets of ydata values
            initial_params              = [1, 0.3,0.3]                                                                             ; % kd Rb Rf
            fitfunc                     = @(params, x) SABRE_onesite_exchange_LmatrixK(params(1), params(2), params(3), K, Mb, Mf, x) ;
            [beta1,R,J,CovB]            = nlinfit(xdata_fit, ydata, fitfunc, initial_params)                                        ;
            coefficients_standard_errors= sqrt(diag(CovB))                                                                          ;
            CSE                         = coefficients_standard_errors                                                              ; 
            fprintf("results: \n")                                                                                                  ;
            fprintf("Model CSS2↔S2_MatrixK kd = %.2f ± %.2f s-1, ka' = %.2f ± %.2f s-1, Rb = %.2f ± %.2f s-1, Rf = %.3f ± %.3f s-1 \n",beta1(1),CSE(1),beta1(1)/K,CSE(1)/K,beta1(2),CSE(2),beta1(3),CSE(3))
            
            % Calculation of the concentrations after fitting for Cs, CsS2 and S
            S                           = S0/(1+3/K)                                                                                ;
            S2                          = S/2                                                                                       ;
            CsS2                        = Ir0                                                                                       ;
            fprintf("[S] = %.2f mM, [CsS2] = %.2f  mM \n",S, CsS2)
            
        case 'Biexponential'  
            fprintf("start to fit with biexponential model \n") 
            K                          = data.K(n)                                                                                  ;                                                                            
            Nt                         = length(data.tau)                                                                           ;
            xdata_fit                  = reshape(data.tau*[1,1],2*Nt,1)                                                             ;
            ydata                      = [data.ey; data.fy]                                                                         ; % the two sets of ydata values
            initial_params             = [-1, 0, 0.5, 0.5, 3, 0.01]                                                              ; % A1, A2, A3, A4,  k, R1 % Initial constant guess
            fitfunc                    = @(params, x) Fit_CA_SEPPSABRE(params(1), params(2), params(3), params(4), params(5),params(6), x) ;
            [beta1,R,J,CovB]           = nlinfit(xdata_fit, ydata, fitfunc, initial_params)                                         ;
            ysim                       = fitfunc(beta1,xdata_fit)                                                                   ;
            SE                         = sqrt(diag(CovB))                                                                           ;
            k                          = beta1(5)                                                                                   ;
            R1                         = beta1(6)                                                                                   ;
            disp('Model Biexponential has Fitted Parameters:')                                                                      ; 
            fprintf('k  = %.3f ± %.3f Hz & R = %.3f ± %.3f Hz & kd = %.3f ± %.3f Hz \n\r',[k,SE(5),R1,SE(6),k/(0.5+1/K),SE(5)/(0.5+1/K)])   ;
     

end
          
            figure("Color","white",'DefaultAxesFontSize',20,'Position',[1500 500 850 800])                                          ;
            semilogx(data.tau, data.ey, 'ob', data.tau, data.fy, 'or')                                                              ;
            hold on                                                                                                                 ;
            x_fit                     = logspace(log10(min(data.tau0)),log10(max(data.tau0)),100)'                                  ;
            x_fit_fit                 = reshape(x_fit*[1,1],2*length(x_fit),1)                                                      ;
            y_fit                     = fitfunc(beta1,x_fit_fit)                                                                    ;
            semilogx(x_fit, y_fit(1:100), 'b',x_fit, y_fit(101:end), 'r')                                                           ;
            ylim([-0.1 1.1])                                                                                                           ;
            xlim([data.tau0(1) data.tau0(end)+20])
            legend('ePy', 'fPy', 'Fitting','Fitting')                                                                               ;
            PAPER                     = [x_fit, y_fit(1:100), y_fit(101:end)]                                                       ;
            %csvwrite(File+'_simdata_'+ Model_type +'.csv',PAPER) 


toc