% this script compares several similutaions which have different Kd (dissociation rate) 
% with an experimental results to know the dissociation rate of the experiment.

clear all; %clear all and delete all previous data
%close all
tic
p = LoadPath();

%% Name of the folder which contains the simulations files %%%%%%%%%%%%%%%% 
System_type{1} = "HHN-1"     ;
System_type{2} = "HHNN-2"    ;
System_type{3} = "HHC-1"     ;
System_type{4} = "HHHC-1"    ;
System_type{5} = "HH-HHHC-1" ;

ESOTHERIC_types{1} = 'SABREESOTHERIC'                 ;
ESOTHERIC_types{2} = 'SABREESOTHERIC_2D_TA_TB'        ;
ESOTHERIC_types{3} = 'SABREESOTHERIC_2D_TA_vdList'    ;
ESOTHERIC_types{4} = 'SABREESOTHERIC_2D_TB_vdList'    ;
ESOTHERIC_types{5} = 'SABREESOTHERIC_TAvd_Multi_Kd'   ;
ESOTHERIC_types{6} = 'SABREESOTHERIC_TBvd_Multi_Kd'   ;
ESOTHERIC_types{7} = 'SABREESOTHERIC_tev'             ;
ESOTHERIC_types{8} = 'SABREESOTHERICtev_Multi_Kd'     ;

System             = System_type{2}                       ;
ESOTHERIC_type     = ESOTHERIC_types{5}                   ;  
ex.Folder          = "out\"+System+"\ESOTHERIC\"+ESOTHERIC_type+"\"+ESOTHERIC_type+"_"      ;

%% Load data of the experimental file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.experiment = "expdata\"+System+"\ESOTHERIC\"+ESOTHERIC_type+"\"                          ; 
temp          = 293                                                                         ;
data_in       = load(ex.experiment+'SABRE_ESOTHERIC_'+temp+'K_adjusted.csv','-ASCII')       ; 

data.tau      = data_in(:,1)                               ;
data.amp      = data_in(:,2)/max(data_in(:,2))             ;

%% Calculating difference between the experimental data and the simulation data 
Kd_range   = 10:0.1:80                                 ; %9:0.1:51
coefficients          = 0.5:0.1:5                      ;
RMSE = zeros(length(Kd_range),1)                       ;
minimumcoefficients        = zeros(length(Kd_range),1) ;
for ik = 1:length(Kd_range)
    ik/length(Kd_range)*100
    tempsimulation = load(ex.Folder+Kd_range(ik)+'.csv','out')   ; % temporarily 
    x = tempsimulation(:,1)                                      ; % tau of each simulation
    y = tempsimulation(:,2)                                      ; % amp of each simulation 
    ynorm  = y(:,1)/max(y(:,1))                                  ; % normalized amp 
    for kk = 1:length(coefficients)
     diff   = (data.amp - coefficients.*ynorm)                   ; % diff   = x-xi 
     power2 = diff.^2                                            ; % power2 = (x-xi)^2
     average  = sqrt(mean(power2))                               ; % RMSE   
     [minv, ind] = min(average, [], 'all', 'linear')             ;
    end
    RMSE (ik) = minv;
    minimumcoefficients (ik) = coefficients(ind); 
end

%% finding the closest simulation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[X, ind] = min(RMSE, [], 'all', 'linear')  ;
disp(ex.Folder+Kd_range(ind)+'.csv','out')
coefficient = minimumcoefficients(ind)     ;

%% load similar simulation of the experimental results %%%%%%%%%%%%%%%%%%%%
Simulation                = load(ex.Folder+Kd_range(ind)+'.csv','out','-ASCII')        ;
SimilarSimulation.tau     = Simulation(:,1)                                            ; % tau of the similar simulation 
SimilarSimulation.amp     = Simulation(:,2)                                            ; % amp of the similar simulation 
SimilarSimulation.normamp = SimilarSimulation.amp(:,1)/max(SimilarSimulation.amp(:,1)) ; % normalized amp of the similar simulation
%% plot the experimental and the similar simulation %%%%%%%%%%%%%%%%%%%%%%% 
figure                                                ;
set(gcf,'color','w')                                  ;
subplot(1,2,1)
plot(1e3*data.tau, data.amp,'r','LineWidth',2)        ;
hold on 
plot(1e3*SimilarSimulation.tau, coefficient*SimilarSimulation.normamp,'b','LineWidth',2);
xlabel('Tau (ms)')                                    ;
ylabel('Amplitude')                                   ;
legend('experimental signal','simulation signal')     ;
title(sprintf("k_d = %.2f s^{-1} & coefficient = %.2f ",[Kd_range(ind),coefficient]))
grid on 

subplot(1,2,2)
plot(Kd_range, RMSE,'b','LineWidth',2)                 ;
xlabel('K_d (s^-^1)')                                  ;
ylabel('RMSE')                                         ;
xlim([0  80])
title('Root Mean Square Error for all K_d')
grid on 

 %% Save the similar simulation with the coefficient %%%%%%%%%%%%%%%%%%%%%%%
% out = [SimilarSimulation.tau ,coefficient*SimilarSimulation.normamp];
% save("expdata\SABREPy_INEPT_"+temp+"K_simulation.csv","out",'-ASCII') % change the name 
toc

