% this script compares several similutaions of SABER-INEPT with different te(s) which have different Kd (dissociation rate) 
% with an experimental results to know the dissociation rate of the experiment.

clear all; %clear all and delete all previous data
%close all
tic
p = LoadPath();

%% Name of the folder which contains the simulations files %%%%%%%%%%%%%%%% 
System_type{1} = "HHN-1"     ;
System_type{2} = "HHNN-2"    ;
System_type{3} = "HHC-1"     ;
System_type{4} = "HHHC-1"    ;
System_type{5} = "HH-HHHC-1" ;

INEPT_types{7} = 'SABREINEPT2tev'                ;
INEPT_types{8} = 'SABREINEPT2tev_Multi_Kd'       ;

System         = System_type{2}                                             ;
INEPT_type     = INEPT_types{8}                                             ; 
ex.Folder      = "out\"+System+"\"+INEPT_type+"\"+INEPT_type+"_"            ; % 

%% Load data of the experimental file %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.experiment  = "expdata\"+System+"\"+INEPT_type+"\"                                 ; 
temp           = 280                                                                  ;
data_in        = load(ex.experiment+'SABREINEPT_'+temp'+'K_adjusted.csv','-ASCII')    ; % change the name in line 100

data.tau       = data_in(:,1)                     ;
data.amp       = data_in(:,2)                     ;
data.norm      = data.amp/max(data.amp(:,1))      ;
%data.norm      = data.amp                         ;
%% Fitting the experimental data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data           = SABREINEPTte_fit_cal(data)                 ;
data.fit.constant
data.fit       = SABREINEPTte(data.fit.constant, data.tau)  ;

%% plot the experimental and the similar simulation %%%%%%%%%%%%%%%%%%%%%%% 
figure
set(gcf,'color','w')                                                                        ;
semilogx(data.tau, data.norm,'O')                                                           ;
hold on 
semilogx(data.tau,data.fit,'r','LineWidth',1)                                               ;
xlabel('Tau (ms)')                                                                          ;
ylabel('Amplitude')                                                                         ;
legend('experimental signal','simulation signal')                                           ;
grid on 

x = data.tau                                                                                ;
p = 'a + b*exp(x*c) + d*exp(x*e)'                                                           ;                                  
startPoints  = [0.1 1 -4.5 2 0.1]                                                           ; % [5.9e5 1 -3 90 -8]
[result gof] = fit(data.tau, data.norm, p,'Start', startPoints)                             ;
coef         = coeffvalues(result)                                                          ; % extracting coefficients 
int          = confint(result)                                                              ; % extracting trusting interval for 95% confidence = 2 sigma
A = coef (1,1);
B = coef (1,2);
C = coef (1,3);
D = coef (1,4);
E = coef (1,5);
yfitted = A + B*exp(x*C) + D*exp(x*E);
figure
set(gcf,'color','w')                                                                        ;
semilogx(data.tau, data.norm,'O')                                                           ;
hold on 
semilogx(data.tau,yfitted,'r','LineWidth',1)                                                ;
xlabel('Tau (ms)')                                                                          ;
ylabel('Amplitude')                                                                         ;
legend('experimental signal','simulation signal')                                           ;
grid on 
result
kd = -C/(1 + E)
toc