%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p=LoadPath();
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System_type{1}="HHN-1"     ;
System_type{2}="HHNN-2"    ;
System_type{3}="HHC-1"     ;
System_type{4}="HHHC-1"    ;
System_type{5}="HH-HHHC-1" ;

System=System_type{1};
ex=Load_SABRE_System(System);
%ex.Folder="out\SLIC_SHEATH_SABRE_"+System+"_data";
%% kinetic parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.fpH= 100;                            % pH2 fraction (1 - 100)%
ex.Kd = 0.01;                           % [s^-1] dissociation rate
ex.Wa = ex.Kd/10;                       % [s^-1] association rate

%%  parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.B0  = 9.4;                           % observation magnetic field [T]
ex.t1v = 1e-3*10';

ex.prebubble = 10;

%% calculate pulsed SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
initial_states{1} = 'phINEPT';
initial_states{2} = 'C1Z3Y+C2Z3Y';
initial_states{3} = 'C1Z3Y';
initial_states{4} = 'C2Z3Y';
initial_state = initial_states{4};


switch initial_state
    case 'phINEPT'
        Yout = sabre_inept_SOT(ex);  
        rS   = Yout.rS;
        rC   = Yout.rC;
    case 'C1Z3Y+C2Z3Y'  
        rC   = DensityMatrix(ex.Sc.U + ex.Sc.norm2('z',1,'y',3) + ex.Sc.norm2('z',2,'y',3));%ex.Sc.norm2)+ ex.Sc.norm2('z',2,'y',3)
        rS   = DensityMatrix(ex.Ss.U);%
    case 'C1Z3Y'  
        rC   = DensityMatrix(ex.Sc.U + ex.Sc.norm2('z',1,'y',3));%ex.Sc.norm2)+ ex.Sc.norm2('z',2,'y',3)
        rS   = DensityMatrix(ex.Ss.U);%
    case 'C2Z3Y'  
        rC   = DensityMatrix(ex.Sc.U + ex.Sc.norm2('z',2,'y',3));%ex.Sc.norm2)+ ex.Sc.norm2('z',2,'y',3)
        rS   = DensityMatrix(ex.Ss.U);%
end


%% spectrum parameters
spec.pulse=0;                 % excitation pulse [rad]
spec.ph1='X'   ;
%spec.phrec='-X';
spec.B0=ex.B0 ;               % observation magnetic field [T]
spec.v0_1H =spec.B0*ex.Sc.gamma{1}/(2*pi); % observation frequency, Hz
spec.v0_15N=spec.B0*ex.Sc.gamma{3}/(2*pi); % observation frequency, Hz
spec.SW=9000    ; % [Hz]
spec.TD=1024    ; % spectral width and number of points in FID

%% calculate spectrum
[spec] = sabre_FID(ex,rS,rC,spec);
%% plot spectrum
types_spec{1}="relative FRQ";
types_spec{2}="absolute FRQ";
% "all" "c", "s", "1H", "15N"... "1H_c", "1H_s", "15N_c", "15N_s"
%plot_spectrum(System,ex,spec,types_spec{2},"all");
plot_spectrum(System,ex,spec,types_spec{2},"c","spectrum")  ;
%plot_spectrum(System,ex,spec,types_spec{2},"s")  ;
%plot_spectrum(System,ex,spec,types_spec{2},"15N");
%plot_4spectra(System,ex,spec,types_spec{2},"all");


%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc
