%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all                                                                  ; % clear all and delete all previous data
tic
p              = LoadPath()                                                ;
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System_type{1} = "HHN-1"                                                   ;
System_type{2} = "HHNN-2"                                                  ;
System_type{3} = "HHC-1"                                                   ;
System_type{4} = "HHHC-1"                                                  ;
System_type{5} = "HH-HHHC-1"                                               ;

System         = System_type{2}                                            ;
ex             = Load_SABRE_System(System)                                 ;
    
%% kinetic parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.fpH         = 0.52                                                      ; % pH2 fraction (1 is 100)
ex.Kd          = 40                                                        ; % [s^-1] dissociation rate
Concentrationofcomplex   = 4.2                                             ; % Concentration of complex [mM] %  4.68  
Concentrationofsubstrate = 42.4                                            ; % Concentration of substrate [mM] % 41
n      = Concentrationofcomplex/Concentrationofsubstrate                   ;
ex.Wa  = ex.Kd*n                                                           ; % [s^-1] association rate
             
%% Sequence to measure %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
INEPT_types{1} = 'SABREINEPT'                                              ;
INEPT_types{2} = 'SABREINEPT_Multi_Kd'                                     ;
INEPT_types{3} = 'SABREINEPTplus'                                          ;
INEPT_types{4} = 'SABREINEPTplus_Multi_Kd'                                 ;
INEPT_types{5} = 'SABREINEPT2'                                             ;
INEPT_types{6} = 'SABREINEPT2_Multi_Kd'                                    ;
INEPT_types{7} = 'SABREINEPT2tev'                                          ;
INEPT_types{8} = 'SABREINEPT2tev_Multi_Kd'                                 ;

INEPT_type     = INEPT_types{1}                                            ;  
ex.Folder      = "out\"+System+"\INEPT\"+INEPT_type+"\"+INEPT_type+"_"     ;  

%%  parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.B0          = 9.4                                                       ; % observation magnetic field [T]
ex.prebubble   = 10                                                        ; % perbubble [s]

%% calculate pulsed SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    switch INEPT_type
        case 'SABREINEPT'
            
        ex.t1v     = 1e-3*[1:1:28, 30:2:122]'                              ; 
        Yout       = sabre_inept_SOT(ex)                                   ; 
        
        case 'SABREINEPT_Multi_Kd'   
            
              ex.t1v      = 1e-3*[1:1:28, 30:2:122]'                       ; 
              Kd_range    = 8:0.1:60                                       ; 
              for  kk     = 1:length(Kd_range)
                   kk/length(Kd_range)*100
                   ex.Kd  = Kd_range(kk)                                   ; 
                   ex.Wa  = ex.Kd*n                                        ;
                   Yout   = sabre_inept_SOT(ex)                            ;
                   out    = [ex.t1v, Yout.c{5}]                            ; % 1Z3Y
                   save(ex.Folder+ex.Kd+'.csv','out','-ASCII')             ;
              end
        case 'SABREINEPTplus'
            
                ex.t1v    = 1e-3*linspace(0,42,43)'                        ;
                ex.t2v    = ex.t1v                                         ;
                Yout      = sabre_ineptplus_SOT(ex)                        ; 
                out       = [ex.t1v,(Yout.c{12}+Yout.c{13})/2]             ; % (3X + 4X)/2
                save(ex.Folder+ex.Kd+'.csv','out','-ASCII')                ;
                
        case 'SABREINEPTplus_Multi_Kd'
            
                ex.t1v  = 1e-3*linspace(0,42,43)'                          ;
                ex.t2v = ex.t1v                                            ;
                  Kd_range    = 8:0.1:60                                   ;
                  for  kk     =  1:length(Kd_range)
                       kk/length(Kd_range)*100
                       ex.Kd  = Kd_range(kk)                               ; 
                       ex.Wa  = ex.Kd*n                                    ;
                       Yout   = sabre_ineptplus_SOT(ex)                    ;
                       out    = [ex.t1v,(Yout.c{12}+Yout.c{13})/2]         ;
                       save(ex.Folder+ex.Kd+'.csv','out','-ASCII')         ;
                  end
                  
        case 'SABREINEPT2'
            
                 ex.t1v       = 1e-3*linspace(0,42,43)'                    ;
                 ex.t2v       = ex.t1v                                     ;
                 ex.tev       = 2                                          ; 
                 Yout         = sabre_inept2_SOT(ex)                       ;
                 
        case 'SABREINEPT2_Multi_Kd' 
            
                 ex.t1v       = 1e-3*linspace(0,42,43)'                    ;
                 ex.t2v       = ex.t1v                                     ;
                 ex.tev       = 2                                          ;
                 Yout         = sabre_inept2_SOT(ex)                       ;
                 out          = [ex.t1v,(Yout.s{6}+Yout.s{9})/2]           ;
                 save(ex.Folder+ex.Kd+'.csv','out','-ASCII')               ;
                 
        case 'SABREINEPT2tev'
            
                 ex.t1v       = 9e-3                                       ; 
                 ex.t2v       = ex.t1v                                     ;
                 ex.taugrad   = 0.002                                      ; % gradients pulses applied for 2 ms before te delays
                 ex.tev       = [0.01:0.01:0.1, 0.2:0.1:1, 2:1:10,20]'     ;
                 Yout         = sabre_inept2tev_SOT(ex)                    ;
                 
        case 'SABREINEPT2tev_Multi_Kd'
            
                 ex.t1v       = 11e-3                                      ; 
                 ex.t2v       = ex.t1v                                     ;
                 ex.taugrad   = 0.002                                      ; % gradients pulses applied for 2 ms before te delays
                 ex.tev       = [0.01:0.01:0.1, 0.2:0.1:1, 2:1:10,20]'     ;
                  Kd_range    = 1:0.1:70                                   ;
                  for  kk     = 1:length(Kd_range)
                       kk/length(Kd_range)*100
                       ex.Kd  = Kd_range(kk)                               ; 
                       ex.Wa  = ex.Kd*n                                    ;
                       Yout   = sabre_inept2tev_SOT(ex)                    ;
                       out    = [ex.tev,((Yout.s{6}+Yout.s{9})/2)']        ;
                       save(ex.Folder+ex.Kd+'.csv','out','-ASCII')         ;
                  end
             
    end
% out = [ex.t1v*1e3, Yout.c{5}];
% save("SABREINEPT.csv","out",'-ASCII')
%% plot %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  switch INEPT_type
      case {'SABREINEPT','SABREINEPT_Multi_Kd'}
            figure                  
            set(gcf,'color','w')                                           ;
            plot(ex.t1v*1e3,Yout.c{5},'b','LineWidth',2)                    %% 1Z3Y
            legend (ex.SOcStr{5}) 
      case {'SABREINEPTplus','SABREINEPTplus_Multi_Kd'}
            figure
            set(gcf,'color','w')                                           ;
            plot(ex.t1v*1e3,(Yout.c{12}+Yout.c{13})/2,'LineWidth',2)       %% (3X + 4X)/2
            legend(ex.SOcStr{12}+"+"+ex.SOcStr{13})
      case {'SABREINEPT2','SABREINEPT2_Multi_Kd'}
            figure
            set(gcf,'color','w')                                           ;
            plot(ex.t1v*1e3,(Yout.s{6}+Yout.s{9})/2,'LineWidth',2)         %% 1Z+2Z/2
            legend(ex.SOsStr{6}+"+"+ex.SOsStr{9})
      case {'SABREINEPT2tev','SABREINEPT2tev_Multi_Kd'}
            figure
            set(gcf,'color','w')                                           ;
            semilogx(ex.tev,(Yout.s{6}+Yout.s{9})/2,'LineWidth',2)         %% 1Z+2Z/2
            legend(ex.SOsStr{6}+"+"+ex.SOsStr{9})
            xlabel('τe (s)')                                               ;
            ylabel('Amplitude')                                            ;
  end 

%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc
