%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all                                                                  ; %clear all and delete all previous data
close all                                                                  ;
tic
p              = LoadPath()                                                ;
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System_type{1} = "HHN-1"                                                   ;
System_type{2} = "HHNN-2"                                                  ;
System_type{3} = "HH-C"                                                    ;
System_type{4} = "HHHC-1"                                                  ;
System_type{5} = "HH-HHHC-1"                                               ;
  
System         = System_type{3}                                            ;
ex             = Load_SABRE_System(System)                                 ;

%% kinetic parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.fpH                   = 1                                               ; % pH2 fraction (1 is 100)
ex.Kd                    = 4                                               ; % [s^-1] dissociation rate
Concentrationofcomplex   = 4                                               ; % Concentration of complex [mM] %  4.68  
Concentrationofsubstrate = 50                                              ; % Concentration of substrate [mM] % 41
n = Concentrationofcomplex/Concentrationofsubstrate                        ;
ex.Wa                    = ex.Kd*n                                         ; % [s^-1] association rate

%% Sequence to measure %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
INEPT_types{1} = 'SABRESEPP'                                               ;
INEPT_types{2} = 'SABRESEPPINEPT'                                          ;
INEPT_types{3} = 'SABRESEPPINEPT_Multi_Kd'                                 ;


INEPT_type     = INEPT_types{2}                                            ;  
ex.Folder      = "out\"+System+"\INEPT\"+INEPT_type+"\"+INEPT_type+"_"     ;  

%%  parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.B0          = 9.4                                                       ; % observation magnetic field [T]
ex.prebubble   = 10                                                        ; % perbubble [s]

%% calculate pulsed SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    switch INEPT_type
        
        case 'SABRESEPP'
            
        ex.t1v  = 1e-3*[1:1:28, 30:2:122]'                                 ;
        Yout    = SABRE_SEPP_SOT(ex)                                       ; 
        
        case 'SABRESEPPINEPT'
            
        ex.t1v  = 1e-3*[1:10:2500]'                                        ;
        ex.tau1 = 1/(4*10.48)                                              ;
        Yout    = SABRE_SEPPINEPT_SOT(ex)                                  ; 
        
        case 'SABRESEPPINEPT_Multi_Kd'   
              ex.t1v   = 1e-3*[1,10:5:95, 100:10:740]'                     ; 
              ex.tau1  = 1/(4*10.5)                                        ;
              Kd_range = 8:0.1:60                                          ; 
              for  kk  = 1:length(Kd_range)
                   kk/length(Kd_range)*100
                   ex.Kd  = Kd_range(kk)                                   ; 
                   ex.Wa  = ex.Kd*n                                        ;
                   Yout   = sabre_inept_SOT(ex)                            ;
                   out    = [ex.t1v, Yout.c{5}]                            ; % 1Z3Y
                   save(ex.Folder+ex.Kd+'.csv','out','-ASCII')             ;
              end
    end
%% plot %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  switch INEPT_type
     case 'SABRESEPP'
            figure                                                         ;
            set(gcf,'color','w')                                           ;
            plot(ex.t1v*1e3,Yout.c{8},'b','LineWidth',2)                   ; %% 1Z3Y
            legend (ex.SOcStr{8:9}) 
      
      case {'SABRESEPPINEPT','SABRESEPPINEPT_Multi_Kd'}
            figure                                                         ;
            set(gcf,'color','w')                                           ;
            plot(ex.t1v*1e3,(Yout.c{3}),'b','LineWidth',2)                    %% 1Z3Y
            legend (ex.SOcStr{3}) 
  end 

%%%%%%%%%%%%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc
