%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
p=LoadPath();
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System=Load_SABRE_System_Name(5);
ex=Load_SABRE_System(System);

ex.Folder="out\SLIC_SHEATH_SABRE_"+System+"_tSLIC_1uT_49.9526uT.mat";
%% change these parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
frq_offset = 0; % [Hz] offset from X spin resonance
% field to v1 conversion for 13C
v1 = 1*1e-6*(ex.Ss.gamma{end}/(2*pi))
ex.timeRFv = linspace(0,120,60);% linspace(0,100,2);          % X nuclei RF pulse time [s]
%% kinetic parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.fpH= 1;                              % pH2 fraction (1 - 100)%
%ex.Kd =10;                             % [s^-1] dissociation rate for MOD2
%ex.Wa =ex.Kd/20;                       % [s^-1] association rate for MOD2
ex.Kd = 10;                             % [s^-1] dissociation rate for exC
%% SLIC parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.B0 = 49.9526*1e-6;                               % observation magnetic field [T]
ex.offsetv = frq_offset; % [Hz] offset from X spin resonance
% RF on 13C
ex.v1v = v1/ex.Ss.g_gh{end};     % in [Hz] for 1H gamma!
%ex.vrfv = -(1+ex.ppmC(end))*ex.Sc.gamma{end}*ex.B0/(2*pi)+ex.offsetv; % resonancing frequency
ex.vrfv = -535;
% RF on 1H
%ex.v1v = linspace(0,60,200)/ex.Ss.g_gh{1};     % in [Hz] for 1H gamma!
%ex.vrfv = -(1+ex.ppmC(1))*ex.Sc.gamma{1}*ex.B0/(2*pi)+ex.offsetv; % resonancing frequency
ex.prebubble = 0.1;
%% Calculate for exC
Yout = sabre_exC_ULF_SLIC(ex);
% plot 1D
plot_all_ULF_SLIC_SABRE_tb(System,Yout.c,ex,ex.show_c,ex.SOcStr,"C in complex")


%% Calculate for MOD2
% Yout = sabre_MOD2_ULF_SLIC(ex);
% % plot 1D
% plot_all_ULF_SLIC_SABRE_tb(System,Yout.s,ex,ex.show_s,ex.SOsStr,"C free")
% plot_all_ULF_SLIC_SABRE_tb(System,Yout.c,ex,ex.show_c,ex.SOcStr,"C in complex")
% display("[Substrate]/[Catalyst] = "+num2str(Yout.SABRE.fs/Yout.SABRE.fc));

%% fit C in Cat
x = ex.timeRFv';
y = squeeze(Yout.c{ex.show_c(1)}(1,1,:));
figure('Color','white','Units',"pixels",'Position', [10 100 600 700])
plot(x,y*100,"LineWidth",1.5);

ax = gca; 
ax.set('FontSize',12,'FontName','Arial');        
title(sprintf(System+"("+"C"+")"+' '+ex.SOcStr{ex.show_c(1)}+', k_d''=%.2f s^-^1',[ex.Kd]),'FontSize',10,'FontName','Arial');
xlabel('time SLIC PULSE (s)','FontSize',12,'FontName','Arial');
ylabel('Polarization (%)'    ,'FontSize',12,'FontName','Arial');

A0=y(end);
B0=y(1)-y(end);
T0=-x(round(end/2))/log((y(round(end/2))-y(end))/(y(1)-y(end)));
opt=fitoptions('Method','NonLinearLeastSquare',...
                    'StartPoint',[A0,B0,T0],...
                     'Lower',[-Inf,-Inf,0],...
                    'Upper',[Inf,Inf,100],...
                    'MaxIter',1e6);
myexp=fittype('A+B*exp(-x/T)','options',opt); %this line define fitting function
[result gof]=fit(x,y,myexp);%goodness-of-fit statistics to the structure gof
coef=coeffvalues(result); %extracting coefficients 
int=confint(result); % extracting trusting interval for 95% confidence =2sigma
meanerror=abs((int(2,:)-int(1,:))/2);

leg= {"13C offset="+num2str(ex.offsetv(1),3)+" Hz, v1 = "+num2str(ex.Ss.g_gh{end}*ex.v1v(1),3)+" Hz";
      "T ="+num2str(result.T)+" s"}; 
hold on
plot(x,result(x)*100,'r')
hold off
legend(leg,'FontSize',12,'FontName','Arial');
result

%% save data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data.System=System;
data.Yout=Yout;
data.ex=ex;
save(ex.Folder,'data');

%% %%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc
