%% start %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; %clear all and delete all previous data
tic
%close all                                                                  ; % close all tabs
LoadPath('AP')
%% Load System %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
System        = Load_System_Name(56)                                       ; % use systems     System{34}="SABRE-AAXX";  System{36}="SABRE-AAX";
ex            = Load_System(System)                                        ;

ex.Folder="out\onefield"+System;
%% Field parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ex.B.start=0e-6;  % T
ex.B.end = 0.5e-6; % T
ex.B.n = 10000;
ex.B.v=linspace(ex.B.start,ex.B.end,ex.B.n)';
ex.T = 1; % s
ex.dt = ex.T/ex.B.n;
%% calculate pulsed SABRE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
r0=DensityMatrix('100%_SingletSpinOrder',ex.S,1,2);
Y.Iop = zeros(ex.B.n,length(ex.SOs));
Y.Pop = zeros(ex.B.n,8);
Y.E = zeros(ex.B.n,8);
    
for ib=1:ex.B.n            
    B=ex.B.v(ib);
    H=2*pi*HZJij(ex.S,ex.PPM,ex.J,B,"full");
    [Q,E] = eig(full(H));    
    r0.val = expm(-1i*ex.dt*H)*r0.val*expm(1i*ex.dt*H);
    Y.Pop(ib,:) = diag(Q\r0.val*Q)';
    Y.E(ib,:) = diag(E)';
    Y.Iop(ib,:)=real(Amplitudes(r0,ex.SOs));                    
end

% %% save data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% save_all_onefield(System,Yout{1}*100,ex);
out = [ex.B.v Y.Iop];
save(ex.Folder+".dat","out","-ASCII");
 
%% rhos
figure("Color","white")
subplot(3,1,1)
plot(ex.B.v,Y.Iop*100,"LineWidth",2);
legend(ex.SOsStr);
xlabel("B (T)");
ylabel("Polarization (%)");
title("Spin operators");

subplot(3,1,2)
plot(ex.B.v,Y.Pop,"LineWidth",2);
%legend(ex.SOsStr);
xlabel("B (T)");
ylabel("Populations");
title("Populations");

subplot(3,1,3)
plot(ex.B.v,Y.E/(2*pi),"LineWidth",2);
%legend(ex.SOsStr);
xlabel("B (T)");
ylabel("Energies (Hz)");
title("Energies");
%%%%%%%%%%%%%%% end %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
toc
