%% Calculate R2 relaxation measured from CPMG
% 10.1002/mrm.1910110304

%% input values
kab = 10000; %s-1, from a to b
kba = 10000; %s-1, from b to a

T2a = 90; % s
T2b = 10; % s
Dnu = 100; % Hz frequency shift
Domega = 2*pi*Dnu; % rad/s frequency shift

tCPMG = logspace(log10(0.01),log10(100),100)*1e-3; % time between two 180, so 2*d20+p180 on Bruker



%%
tau_a = 1/kab; % s, average lifetime of a
tau_b = 1/kba; % s, average lifetime of a

tau = 1/((1/tau_a)+(1/tau_b)); 

Pa = tau/tau_b; % fractional populations
Pb = tau/tau_a; % fractional populations

R2m = Pa/T2a + Pb/T2b; % common relaxation rate
T2m = 1/R2m; % common relaxation time

R2CPMG = R2m + Pa*Pb*Domega^2*tau*(1-(2*tau./tCPMG).*tanh(tCPMG/(2*tau))); % measured with CPMG
R2m0 = R2m + Pa*Pb*Domega^2*tau; % real T2; 

%% check for validity
x1 = (1/tau)/(1/T2b-1/T2a); %should be >>1
x2 = (1/tau)/Domega; %should be >>1
fprintf("x1 = %f should be much more than 1 \n",x1)
fprintf("x2 = %f should be much more than 1 \n",x2)


semilogx(tCPMG,R2CPMG,"LineWidth",3,"LineStyle","-")
hold on
semilogx(tCPMG,tCPMG*0+R2m0,"LineWidth",2,"LineStyle","--")
hold off
xlabel("tau CPMG = 2*D20 + p180 (ms)")
ylabel("R2 (s-1)")
legend(["observed R_2 with CPMG", "real R_2"])



