clear all
close all
tic
% Load the data
name          = 'ala_Temp298K'                                             ;    
filepath      = fullfile('ALa_Gly_data', [name '.txt'])                    ;  % Change filename accordingly
data          = load(filepath)                                             ;
% Separate by first column
data1         = data(data(:,1) == 1, :)                                    ;
data2         = data(data(:,1) == 2, :)                                    ;

% Extract the integrals (4th column)
I1            = data1(:,4)                                                 ;
I1norm        = I1/max(abs(I1))                                            ; 
I2            = data2(:,4)                                                 ;
I2norm        = I2/max(abs(I2))                                            ;


% Create index column
xdata         = ((1:length(I1norm))/1000)'                                 ;

% Prepare data for export
output1       = [xdata/1000, I1norm]                                       ;
output2       = [xdata/1000, I2norm]                                       ;


%%%%%% fitting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fitting_function  = @(I, x) sin(2*pi*I(1)*xdata) .* sin(2*pi*I(2)*xdata) .* exp(-I(3)*xdata);

% Initial guesses for parameters
I                 = [20, 0.1, 0.2];  % [J1_guess, r_guess]

%% %%%%%%%%%%%%%% Perform the fitting using nlinfit %%%%%%%%%%%%%%%%%%%%%%%
[beta1,R,J,CovB]  = nlinfit(xdata,  I1norm, fitting_function, I)           ;

ysim1             = fitting_function(beta1,xdata)                          ;
SE                = sqrt(diag(CovB))                                       ;

%%%%%%%%%%%%%%%%%%% Display the fitted parameters %%%%%%%%%%%%%%%%%%%%%%%%%
J1                = beta1(1)                                               ;
J2                = beta1(2)                                               ;
R1                = beta1(3)                                               ;

disp('Fitted Parameters:')                                                 ;
fprintf('J1  = %.3f ± %.3f s^-1 \n\r',[J1,SE(1)])                          ;
fprintf('J2 = %.3f ± %.3f s^-1 \n\r',[J2,SE(2)])                           ;
fprintf('R = %.3f ± %.3f s^-1 \n\r',[R1,SE(3)])                            ;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure("Color","white",'DefaultAxesFontSize',20,'Position',[400 100 2000 800]); % initial from left, initial from bottom, width, height

subplot(1,2,1)                                                             ; % First subplot
plot(xdata, I1norm, 'Ob',xdata, ysim1,'b')                                 ;
title('Integrals1')                                                        ;
xlabel('Index')                                                            ;
ylabel('Integrals')                                                        ;
%axis([0,2.2,-1,1.1])
grid on
subplot(1,2,2)                                                             ; 
plot(xdata, I2norm, 'Or')                                                  ;
title('Integrals2')                                                        ;
xlabel("𝜏_e (s)",'Fontsize',22)                                            ;
ylabel('Integrals')                                                        ;
%axis([0,2.2,-1,1.1])
grid on                                                                    ;
figure("Color","white",'DefaultAxesFontSize',20,'Position',[400 100 2000 800]);% initial from left, initial from bottom, width, height
plot(xdata, I1norm-I2norm,'Oblack')                                        ;
title('Integrals1-integrals2')                                             ;
xlabel("𝜏_e (s)",'Fontsize',22)                                            ;
ylabel('Integrals')                                                        ;
%axis([0,2.2,-2,2.1])
grid on                                                                    ;

% save([name '_1.txt'], 'I1', '-ascii')                                     ;
% save([name '_2.txt'], 'I2', '-ascii')                                     ;

toc