function ex = Load_System(type,varargin)
ex.System=type;

    switch type 
        case "Acetone-spin1"
            ex.S = SpinOperators(1,{'1H','1H'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(1,'y'),ex.S.P(1,'z')};
            PPM=2.05*1e-6;%chemical shift
            Jij=zeros(1);                                   
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=1;                        
            ex.RegNuc = 1;

        case "EthD3-PyruvateD3-spin2"
            ex.S = SpinOperators(2,{'1H','1H'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(1,'z'),ex.S.P(2,'z')};
            PPM=[4.2501, 1.2941]*1e-6;%chemical shift
            Jij=zeros(2);
            Jij(1,2)=7.12;            
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];            
            ex.n1=1;
            ex.n2=2;
        case "Eth-Acetate-d3-spin2"
            ex.S = SpinOperators(2,{'1H','1H'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(1,'z'),ex.S.P(2,'z')};
            PPM=[4.037, 1.178]*1e-6;%chemical shift
            Jij=zeros(2);
            Jij(1,2)=7.1;            
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];            
            ex.RegNuc = 1:2;
            ex.n1=1;
            ex.n2=2;
        case "Eth-Acetate-spin5"
            ex.S = SpinOperators(5,{'1H','1H','1H','1H','1H'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(4,'x'),ex.S.P(5,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(3,'y'),ex.S.P(4,'y'),ex.S.P(5,'y'),ex.S.P(1,'z'),ex.S.P(2,'z'),ex.S.P(3,'z'),ex.S.P(4,'z'),ex.S.P(5,'z')};
            PPM=[4.037,4.037, 1.178,1.178,1.178]*1e-6;%chemical shift
            Jij=zeros(5);
            Jhh=7.1;
            J00=-15;
            J11=14;
            Jij(1,2)=J00;            
            Jij(1,3)=Jhh;Jij(2,3)=Jhh;
            Jij(1,4)=Jhh;Jij(2,4)=Jhh;Jij(3,4)=J11;
            Jij(1,5)=Jhh;Jij(2,5)=Jhh;Jij(3,5)=J11;Jij(4,5)=J11;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5];            
            ex.RegNuc = 1:5;
            ex.n1=1;
            ex.n2=3;
        case "Eth-Acetate-d3-spin3"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P(3,'x'),ex.S.P(3,'y'),ex.S.P(3,'z')};
            PPM=[4.037, 1.178, 174]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=7.1;
            Jij(1,3)=3.1;Jij(2,3)=-0.13*1;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
        case "Eth-Acetate-d3-spin3-sCH2"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[4.037, 1.178, 174]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=7.1;
            Jij(1,3)=3.1;Jij(2,3)=-0.13;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[1];
            ex.eH.all=[1,2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
        case "Eth-Acetate-spin6"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P(6,'x'),ex.S.P(6,'y'),ex.S.P(6,'z')};
            d1=4.27;
            d2=2.42;
            PPM=[d1,d1,d2,d2,d2,174]*1e-6;%chemical shift
            J12=7.15;
            J13=3.06;
            J23=-0.15;
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=J13;Jij(2,6)=J13;Jij(3,6)=J23;Jij(4,6)=J23;Jij(5,6)=J23;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5];
            ex.eC=[6]; 
            ex.n1=1;
            ex.n2=3;
        case "Eth-Acetate-spin6-sCH2"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',6),ex.S.P('y',6),ex.S.P('z',6)};
            d1=4.27;
            d2=2.42;
            PPM=[d1,d1,d2,d2,d2,174]*1e-6;%chemical shift
            J12=7.15;
            J13=3.06;
            J23=-0.15;
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=J13;Jij(2,6)=J13;Jij(3,6)=J23;Jij(4,6)=J23;Jij(5,6)=J23;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[1 2];
            ex.eH.all=[1 2 3 4 5];
            ex.eC=[6];           
            ex.n1=1;
            ex.n2=3;
        case "Eth-Acetate-spin9"
            ex.S = SpinOperators(9,{'1H','1H','1H','1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',9),ex.S.P('y',9),ex.S.P('z',9)};
            d1=4.27;
            d2=2.42;
            d3=1.5;%?
            PPM=[d1,d1,d2,d2,d2,d3,d3,d3,174]*1e-6;%chemical shift
            J12=7.15;
            J13=3.06;
            J23=-0.15;
            J43=-6.82;
            J00=-16;
            Jij=zeros(9);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=000;Jij(2,6)=000;Jij(3,6)=000;Jij(4,6)=000;Jij(5,6)=000;
            Jij(1,7)=000;Jij(2,7)=000;Jij(3,7)=000;Jij(4,7)=000;Jij(5,7)=000;Jij(6,7)=J00;
            Jij(1,8)=000;Jij(2,8)=000;Jij(3,8)=000;Jij(4,8)=000;Jij(5,8)=000;Jij(6,8)=J00;Jij(7,8)=J00;
            Jij(1,9)=J13;Jij(2,9)=J13;Jij(3,9)=J23;Jij(4,9)=J23;Jij(5,9)=J23;Jij(6,9)=J43;Jij(7,9)=J43;Jij(8,9)=J43;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5 6 7 8];
            ex.eC=[9]; 
            ex.n1=1;
            ex.n2=3;
        case "Eth-Acetate-spin9-sCH2"
            ex.S = SpinOperators(9,{'1H','1H','1H','1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',9),ex.S.P('y',9),ex.S.P('z',9)};
            d1=4.27;
            d2=2.42;
            d3=1.5;%?
            PPM=[d1,d1,d2,d2,d2,d3,d3,d3,174]*1e-6;%chemical shift
            J12=7.15;
            J13=3.06;
            J23=-0.15;
            J43=-6.82;
            J00=-16;
            Jij=zeros(9);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=000;Jij(2,6)=000;Jij(3,6)=000;Jij(4,6)=000;Jij(5,6)=000;
            Jij(1,7)=000;Jij(2,7)=000;Jij(3,7)=000;Jij(4,7)=000;Jij(5,7)=000;Jij(6,7)=J00;
            Jij(1,8)=000;Jij(2,8)=000;Jij(3,8)=000;Jij(4,8)=000;Jij(5,8)=000;Jij(6,8)=J00;Jij(7,8)=J00;
            Jij(1,9)=J13;Jij(2,9)=J13;Jij(3,9)=J23;Jij(4,9)=J23;Jij(5,9)=J23;Jij(6,9)=J43;Jij(7,9)=J43;Jij(8,9)=J43;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;            
            ex.eH.sel=[1 2];
            ex.eH.all=[1 2 3 4 5 6 7 8];
            ex.eC=[9];           
            ex.n1=1;
            ex.n2=3;
            
        case "Eth-Pyruvate-spin9"
            ex.S = SpinOperators(9,{'1H','1H','1H','1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',9),ex.S.P('y',9),ex.S.P('z',9)};
            d1=4.27;
            d2=2.43;
            d3=1.32;%?
            PPM=[d1,d1,d2,d2,d2,d3,d3,d3,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;
            J43=1.47;
            J00=-16;
            Jij=zeros(9);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=000;Jij(2,6)=000;Jij(3,6)=000;Jij(4,6)=000;Jij(5,6)=000;
            Jij(1,7)=000;Jij(2,7)=000;Jij(3,7)=000;Jij(4,7)=000;Jij(5,7)=000;Jij(6,7)=J00;
            Jij(1,8)=000;Jij(2,8)=000;Jij(3,8)=000;Jij(4,8)=000;Jij(5,8)=000;Jij(6,8)=J00;Jij(7,8)=J00;
            Jij(1,9)=J13;Jij(2,9)=J13;Jij(3,9)=J23;Jij(4,9)=J23;Jij(5,9)=J23;Jij(6,9)=J43;Jij(7,9)=J43;Jij(8,9)=J43;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5 6 7 8];
            ex.eC=[9]; 
            ex.n1=1;
            ex.n2=3;
            
        case "Eth-PyruvateD3-spin9"
            ex.S = SpinOperators(9,{'1H','2H','1H','2H','2H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',9),ex.S.P('y',9),ex.S.P('z',9)};
            f=ex.S.g_gh{2};            
            d1=4.27;
            d2=2.43;
            d3=1.32;%?
            PPM=[d1,d1,d2,d2,d2,d3,d3,d3,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;
            J43=1.47;
            J00=-16;
            Jij=zeros(9);
            Jij(1,2)=J00*f;
            Jij(1,3)=J12;  Jij(2,3)=J12*f;
            Jij(1,4)=J12*f;Jij(2,4)=J12*f*f;Jij(3,4)=J00*f;
            Jij(1,5)=J12*f;Jij(2,5)=J12*f*f;Jij(3,5)=J00*f;Jij(4,5)=J00*f*f;
            Jij(1,6)=000;  Jij(2,6)=000*f;  Jij(3,6)=000;  Jij(4,6)=000*f;Jij(5,6)=000*f;
            Jij(1,7)=000;  Jij(2,7)=000*f;  Jij(3,7)=000;  Jij(4,7)=000*f;Jij(5,7)=000*f;Jij(6,7)=J00;
            Jij(1,8)=000;  Jij(2,8)=000*f;  Jij(3,8)=000;  Jij(4,8)=000*f;Jij(5,8)=000*f;Jij(6,8)=J00;Jij(7,8)=J00;
            Jij(1,9)=J13  ;Jij(2,9)=J13*f;  Jij(3,9)=J23;  Jij(4,9)=J23*f;Jij(5,9)=J23*f;Jij(6,9)=J43;Jij(7,9)=J43;Jij(8,9)=J43;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5 6 7 8];
            ex.eC=[9]; 
            ex.n1=1;
            ex.n2=3;
            
            
        case "EthD3-Pyruvate-spin6"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P(6,'x'),ex.S.P(6,'y'),ex.S.P(6,'z')};                        
            d1=4.27;
            d2=1.32;
            d3=2.43;
            PPM=[d1,d2,d3,d3,d3,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;
            J43=1.47;
            J00=-16;
            Jij=zeros(6);            
            Jij(1,2)=J12;                          
            Jij(1,3)=000;  Jij(2,3)=000;  
            Jij(1,4)=000;  Jij(2,4)=000;  Jij(3,4)=J00;
            Jij(1,5)=000;  Jij(2,5)=000;  Jij(3,5)=J00; Jij(4,5)=J00;
            Jij(1,6)=J13;  Jij(2,6)=J23;  Jij(3,6)=J43; Jij(4,6)=J43; Jij(5,6)=J43;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5];
            ex.eC=[6]; 
            ex.n1=1;
            ex.n2=2;
            


        case "EthD3-PyruvateD1-spin5"
            ex.S = SpinOperators(5,{'1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P(5,'x'),ex.S.P(5,'y'),ex.S.P(5,'z')};                        
            d1=4.27;
            d2=1.32;
            d3=2.43;
            PPM=[d1,d2,d3,d3,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;
            J43=1.47;
            J00=-16;
            Jij=zeros(5);            
            Jij(1,2)=J12;                          
            Jij(1,3)=000;  Jij(2,3)=000;  
            Jij(1,4)=000;  Jij(2,4)=000;  Jij(3,4)=J00;            
            Jij(1,5)=J13;  Jij(2,5)=J23;  Jij(3,5)=J43; Jij(4,5)=J43;
            Jij=Jij+Jij';%Hz

            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4];
            ex.eC=[5]; 
            ex.n1=1;
            ex.n2=2;
                   
        case "EthD3-PyruvateD2-spin4"
            ex.S = SpinOperators(4,{'1H','1H','1H','13C'});
            ex.SOs={ex.S.P(4,'x'),ex.S.P(4,'y'),ex.S.P(4,'z')};                        
            d1=4.27;
            d2=1.32;
            d3=2.43;
            PPM=[d1,d2,d3,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;
            J43=1.47;
            J00=-16;
            Jij=zeros(4);            
            Jij(1,2)=J12;                          
            Jij(1,3)=000;  Jij(2,3)=000;              
            Jij(1,4)=J13;  Jij(2,4)=J23;  Jij(3,4)=J43; 
            Jij=Jij+Jij';%Hz

            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3];
            ex.eC=[4]; 
            ex.n1=1;
            ex.n2=2;

        case "EthD3-PyruvateD3-spin3"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P(3,'x'),ex.S.P(3,'y'),ex.S.P(3,'z')};
            
            d1=4.27;
            d2=1.32;            
            PPM=[d1,d2,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;                        
            Jij=zeros(3);
            Jij(1,2)=J12;
            Jij(1,3)=J13;Jij(2,3)=J23;                        
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];
            ex.eC=[3]; 
            ex.n1=1;
            ex.n2=2;

         case "Eth-PyruvateD6-spin9"
            ex.S = SpinOperators(9,{'1H','2H','1H','2H','2H','2H','2H','2H','13C'});
            ex.SOs={ex.S.P('x',9),ex.S.P('y',9),ex.S.P('z',9)};
            f=ex.S.g_gh{2};            
            d1=4.27;
            d2=1.32;
            d3=2.43;%?
            PPM=[d1,d1,d2,d2,d2,d3,d3,d3,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;
            J43=1.47;
            J00=-16;
            Jij=zeros(9);
            Jij(1,2)=J00*f;
            Jij(1,3)=J12;  Jij(2,3)=J12*f;
            Jij(1,4)=J12*f;Jij(2,4)=J12*f*f;Jij(3,4)=J00*f;
            Jij(1,5)=J12*f;Jij(2,5)=J12*f*f;Jij(3,5)=J00*f;Jij(4,5)=J00*f*f;
            Jij(1,6)=000*f;Jij(2,6)=000*f*f;Jij(3,6)=000*f;Jij(4,6)=000*f*f;Jij(5,6)=000*f*f;
            Jij(1,7)=000*f;Jij(2,7)=000*f*f;Jij(3,7)=000*f;Jij(4,7)=000*f*f;Jij(5,7)=000*f*f;Jij(6,7)=J00*f*f;
            Jij(1,8)=000*f;Jij(2,8)=000*f*f;Jij(3,8)=000*f;Jij(4,8)=000*f*f;Jij(5,8)=000*f*f;Jij(6,8)=J00*f*f;Jij(7,8)=J00*f*f;
            Jij(1,9)=J13;  Jij(2,9)=J13*f;  Jij(3,9)=J23;  Jij(4,9)=J23*f;  Jij(5,9)=J23*f;  Jij(6,9)=J43*f;  Jij(7,9)=J43*f;  Jij(8,9)=J43*f;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5 6 7 8];
            ex.eC=[9]; 
            ex.n1=1;
            ex.n2=3;   
                                   
        case "Eth-Pyruvate-spin9-sCH2"
            ex.S = SpinOperators(9,{'1H','1H','1H','1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',9),ex.S.P('y',9),ex.S.P('z',9)};
            ex.SOs1H={ex.S.P('x',1)+ex.S.P('x',2),...
                      ex.S.P('y',1)+ex.S.P('y',2),...
                      ex.S.P('z',1)+ex.S.P('z',2)};
            d1=4.27;
            d2=2.43;
            d3=1.32;%?
            PPM=[d1,d1,d2,d2,d2,d3,d3,d3,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;
            J43=1.47;
            J00=-16;
            Jij=zeros(9);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=000;Jij(2,6)=000;Jij(3,6)=000;Jij(4,6)=000;Jij(5,6)=000;
            Jij(1,7)=000;Jij(2,7)=000;Jij(3,7)=000;Jij(4,7)=000;Jij(5,7)=000;Jij(6,7)=J00;
            Jij(1,8)=000;Jij(2,8)=000;Jij(3,8)=000;Jij(4,8)=000;Jij(5,8)=000;Jij(6,8)=J00;Jij(7,8)=J00;
            Jij(1,9)=J13;Jij(2,9)=J13;Jij(3,9)=J23;Jij(4,9)=J23;Jij(5,9)=J23;Jij(6,9)=J43;Jij(7,9)=J43;Jij(8,9)=J43;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;            
            ex.eH.sel=[1 2];
            ex.eH.all=[1 2 3 4 5 6 7 8];
            ex.eC=[9];           
            ex.n1=1;
            ex.n2=3;
            
                   
        case "Eth-PyruvateD6-spin3-sCH2"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            ex.SOs1H={ex.S.P('x',1),...
                      ex.S.P('y',1),...
                      ex.S.P('z',1)};
            
            d1=4.27;
            d2=2.43;            
            PPM=[d1,d2,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=-0.1;                        
            Jij=zeros(3);
            Jij(1,2)=J12;
            Jij(1,3)=J13;Jij(2,3)=J23;                        
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[1];
            ex.eH.all=[1 2];
            ex.eC=[3]; 
            ex.n1=1;
            ex.n2=2;
            
            
         case "PLAC-spins-6"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','31P','13C'});
            ex.SOs={ex.S.P('x',6),ex.S.P('y',6),ex.S.P('z',6)};
            d1=4;%tentative 
            d2=1;%tentative 
            d31P=0;%not relevant
            PPM=[d1,d2,d2,d2,d31P,174]*1e-6;%chemical shift
            J12=6.9;
            J1C=-3.8;%+-
            J2C=4.07;
            J1P=8.6;
            J2P=0;
            JCP=6.52;
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J12;
            Jij(1,3)=J12;Jij(2,3)=J00;
            Jij(1,4)=J12;Jij(2,4)=J00;Jij(3,4)=J00;
            Jij(1,5)=J1P;Jij(2,5)=J2P;Jij(3,5)=J2P;Jij(4,5)=J2P;
            Jij(1,6)=J1C;Jij(2,6)=J2C;Jij(3,6)=J2C;Jij(4,6)=J2C;Jij(5,6)=JCP;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4];
            ex.eC=[6]; 
            ex.n1=1;
            ex.n2=2;
        case "PLAC-spins-6-sCH"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','31P','13C'});
            ex.SOs={ex.S.P('x',6),ex.S.P('y',6),ex.S.P('z',6)};
            d1=4;%tentative 
            d2=1;%tentative 
            d31P=0;%not relevant
            PPM=[d1,d2,d2,d2,d31P,174]*1e-6;%chemical shift
            J12=6.9;
            J1C=-3.8;%+-
            J2C=4.07;
            J1P=8.6;
            J2P=0;
            JCP=6.52;
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J12;
            Jij(1,3)=J12;Jij(2,3)=J00;
            Jij(1,4)=J12;Jij(2,4)=J00;Jij(3,4)=J00;
            Jij(1,5)=J1P;Jij(2,5)=J2P;Jij(3,5)=J2P;Jij(4,5)=J2P;
            Jij(1,6)=J1C;Jij(2,6)=J2C;Jij(3,6)=J2C;Jij(4,6)=J2C;Jij(5,6)=JCP;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[1];
            ex.eH.all=[1 2 3 4];
            ex.eC=[6]; 
            ex.n1=1;
            ex.n2=2;     
            
        case "PLAC-spins-6-sCH3"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','31P','13C'});
            ex.SOs={ex.S.P('x',6),ex.S.P('y',6),ex.S.P('z',6)};
            d1=4;%tentative 
            d2=1;%tentative 
            d31P=0;%not relevant
            PPM=[d1,d2,d2,d2,d31P,174]*1e-6;%chemical shift
            J12=6.9;
            J1C=-3.8;%+-
            J2C=4.07;
            J1P=8.6;
            J2P=0;
            JCP=6.52;
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J12;
            Jij(1,3)=J12;Jij(2,3)=J00;
            Jij(1,4)=J12;Jij(2,4)=J00;Jij(3,4)=J00;
            Jij(1,5)=J1P;Jij(2,5)=J2P;Jij(3,5)=J2P;Jij(4,5)=J2P;
            Jij(1,6)=J1C;Jij(2,6)=J2C;Jij(3,6)=J2C;Jij(4,6)=J2C;Jij(5,6)=JCP;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[2 3 4];
            ex.eH.all=[1 2 3 4];
            ex.eC=[6]; 
            ex.n1=1;
            ex.n2=2;  
            
        case "PLACd2-spins-4"
            ex.S = SpinOperators(4,{'1H','1H','31P','13C'});
            ex.SOs={ex.S.P('x',4),ex.S.P('y',4),ex.S.P('z',4)};
            d1=4;%tentative 
            d2=1;%tentative 
            d31P=0;%not relevant
            PPM=[d1,d2,d31P,174]*1e-6;%chemical shift
            J12=6.9;
            J1C=-3.8;%+-
            J2C=4.07;
            J1P=8.6;
            J2P=0;
            JCP=6.52;
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J12;
            Jij(1,3)=J1P;Jij(2,3)=J2P;            
            Jij(1,4)=J1C;Jij(2,4)=J2C;Jij(3,4)=JCP;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];
            ex.eC=[4]; 
            ex.n1=1;
            ex.n2=2;
        case "PLACd2-spins-4-sCH"
            ex.S = SpinOperators(4,{'1H','1H','31P','13C'});
            ex.SOs={ex.S.P('x',4),ex.S.P('y',4),ex.S.P('z',4)};
            d1=4;%tentative 
            d2=1;%tentative 
            d31P=0;%not relevant
            PPM=[d1,d2,d31P,174]*1e-6;%chemical shift
            J12=6.9;
            J1C=-3.8;%+-
            J2C=4.07;
            J1P=8.6;
            J2P=0;
            JCP=6.52;
            J00=-16;
            Jij=zeros(4);
            Jij(1,2)=J12;
            Jij(1,3)=J1P;Jij(2,3)=J2P;            
            Jij(1,4)=J1C;Jij(2,4)=J2C;Jij(3,4)=JCP;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[1];
            ex.eH.all=[1 2];
            ex.eC=[4]; 
            ex.n1=1;
            ex.n2=2;   
            
        case "PLACd2-spins-4-sCH3"
            ex.S = SpinOperators(4,{'1H','1H','31P','13C'});
            ex.SOs={ex.S.P('x',4),ex.S.P('y',4),ex.S.P('z',4)};
            d1=4;%tentative 
            d2=1;%tentative 
            d31P=0;%not relevant
            PPM=[d1,d2,d31P,174]*1e-6;%chemical shift
            J12=6.9;
            J1C=-3.8;%+-
            J2C=4.07;
            J1P=8.6;
            J2P=0;
            JCP=6.52;
            J00=-16;
            Jij=zeros(4);
            Jij(1,2)=J12;
            Jij(1,3)=J1P;Jij(2,3)=J2P;            
            Jij(1,4)=J1C;Jij(2,4)=J2C;Jij(3,4)=JCP;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[2];
            ex.eH.all=[1 2];
            ex.eC=[4]; 
            ex.n1=1;
            ex.n2=2;  
            
        case "HEP-d8"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[2.41, 1.14, 174]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=7.57;
            Jij(1,3)=7.24;Jij(2,3)=-5.62;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
            
        case 'HEP-d8-sCH3'
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[2.41, 1.14, 174]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=7.57;
            Jij(1,3)=7.24;Jij(2,3)=-5.62;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[2];
            ex.eH.all=[1,2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
        case 'HEP-d8-sCH2'
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[2.41, 1.14, 174]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=7.57;
            Jij(1,3)=7.24;Jij(2,3)=-5.62;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[1];
            ex.eH.all=[1,2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
             
        case "HEP-d3-spins-5"
            ex.S = SpinOperators(5,{'1H','1H','13C','1H','1H'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[2.41, 1.14, 174, 3.7, 3.7]*1e-6;%chemical shift
            Jij=zeros(5);
            Jij(1,2)=7.57;
            Jij(1,3)=7.24;Jij(2,3)=-5.62;
            Jij(1,4)=0000;Jij(2,4)=00000;Jij(3,4)=3.1;
            Jij(1,5)=0000;Jij(2,5)=00000;Jij(3,5)=3.1;Jij(4,5)=-15;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 4 5];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
            
        case "HEP-d3-spins-5-sCH3"
            ex.S = SpinOperators(5,{'1H','1H','13C','1H','1H'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[2.41, 1.14, 174, 3.7, 3.7]*1e-6;%chemical shift
            Jij=zeros(5);
            Jij(1,2)=7.57;
            Jij(1,3)=7.24;Jij(2,3)=-5.62;
            Jij(1,4)=0000;Jij(2,4)=00000;Jij(3,4)=3.1;
            Jij(1,5)=0000;Jij(2,5)=00000;Jij(3,5)=3.1;Jij(4,5)=-15;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;            
            ex.eH.sel=[2];
            ex.eH.all=[1 2 4 5];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
            
        case "HEP-d3-spins-5-sCH2"
            ex.S = SpinOperators(5,{'1H','1H','13C','1H','1H'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[2.41, 1.14, 174, 3.7, 3.7]*1e-6;%chemical shift
            Jij=zeros(5);
            Jij(1,2)=7.57;
            Jij(1,3)=7.24;Jij(2,3)=-5.62;
            Jij(1,4)=0000;Jij(2,4)=00000;Jij(3,4)=3.1;
            Jij(1,5)=0000;Jij(2,5)=00000;Jij(3,5)=3.1;Jij(4,5)=-15;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;            
            ex.eH.sel=[1];
            ex.eH.all=[1 2 4 5];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
            
            
        case "HEP-spins-6"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',6),ex.S.P('y',6),ex.S.P('z',6)};
            d1=2.41;
            d2=1.14;
            PPM=[d1,d1,d2,d2,d2,174]*1e-6;%chemical shift
            J12=7.57;
            J13=7.24;
            J23=-5.62;            
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=J13;Jij(2,6)=J13;Jij(3,6)=J23;Jij(4,6)=J23;Jij(5,6)=J23;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5];
            ex.eC=[6]; 
            ex.n1=1;
            ex.n2=3;
            

        case "HEP-spins-6-sCH3"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',6),ex.S.P('y',6),ex.S.P('z',6)};
            d1=2.41;
            d2=1.14;
            PPM=[d1,d1,d2,d2,d2,174]*1e-6;%chemical shift
            J12=7.57;
            J13=7.24;
            J23=-5.62;
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=J13;Jij(2,6)=J13;Jij(3,6)=J23;Jij(4,6)=J23;Jij(5,6)=J23;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[3 4 5];
            ex.eH.all=[1 2 3 4 5];
            ex.eC=[6]; 
            ex.n1=1;
            ex.n2=3;
            
        case "HEP-spins-6-sCH2"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','1H','13C'});
            ex.SOs={ex.S.P('x',6),ex.S.P('y',6),ex.S.P('z',6)};
            d1=2.41;
            d2=1.14;
            PPM=[d1,d1,d2,d2,d2,174]*1e-6;%chemical shift
            J13=7.24;
            J23=-5.62;
            J23=7.24;
            J00=-16;
            Jij=zeros(6);
            Jij(1,2)=J00;
            Jij(1,3)=J12;Jij(2,3)=J12;
            Jij(1,4)=J12;Jij(2,4)=J12;Jij(3,4)=J00;
            Jij(1,5)=J12;Jij(2,5)=J12;Jij(3,5)=J00;Jij(4,5)=J00;
            Jij(1,6)=J13;Jij(2,6)=J13;Jij(3,6)=J23;Jij(4,6)=J23;Jij(5,6)=J23;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[1 2];
            ex.eH.all=[1 2 3 4 5];
            ex.eC=[6]; 
            ex.n1=1;
            ex.n2=3;     
        
            
        case "ABX_7Hz"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[3, 0, 170]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=7;
            Jij(1,3)=3.1;Jij(2,3)=-0.13;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            
            ex.eH=[1,2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
            
        case "ABX_7Hz-sA"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[3, 0, 170]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=7;
            Jij(1,3)=3.1;Jij(2,3)=-0.13;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH.sel=[1];
            ex.eH.all=[1,2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
            
        case "SABRE-AAXX-sel"
            ex.S = SpinOperators(4,{'1H','1H','15N','15N'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            ex.SOs1H={ex.S.P('x',1)+ex.S.P('x',2),...
                      ex.S.P('y',1)+ex.S.P('y',2),...
                      ex.S.P('z',1)+ex.S.P('z',2)};
            PPM=[0, 0, 170, 170]*1e-6;%chemical shift
            Jij=zeros(4);
            JHH0=-8;
            JNHt=-22;
            JNHc=0;
            
            Jij(1,2)=JHH0;
            Jij(1,3)=JNHt;Jij(2,3)=JNHc;
            Jij(1,4)=JNHc;Jij(2,4)=JNHt;Jij(3,4)=0;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            
            
            ex.eH.sel=[1,2];
            ex.eH.all=[1,2];            
            ex.eC=[3,4];
            ex.n1=1;
            ex.n2=2;
            
            
        case "SABRE-AAXX"
            ex.S     = SpinOperators(4,{'1H','1H','15N','15N'})            ;
            ex.SOs   = {ex.S.P(3,'x'),ex.S.P(3,'y'),ex.S.P(3,'z')}         ;
            PPM      = [0, 0, 100, 100]*1e-6                               ; % chemical shift
            Jij      = zeros(4)                                            ;
            JHH0     = -8                                                  ; 
            JNHt     = -22                                                 ; 
            JNHc     = 0                                                   ; 
            
            Jij(1,2) = JHH0                                                ;
            Jij(1,3) = JNHt     ;  Jij(2,3) = JNHc                         ;
            Jij(1,4) = JNHc     ;  Jij(2,4) = JNHt   ;  Jij(3,4) = 0       ;
            Jij      = Jij+Jij'                                            ;%Hz
            
            ex.J     = Jij                                                 ;
            ex.PPM   = PPM                                                 ;
            
            ex.eH    = [1,2]                                               ;
            ex.eC    = [3,4]                                               ;
            ex.n1    = 1                                                   ;
            ex.n2    = 2                                                   ;
            
            
            
        case "SABRE-AAX-sel"
            ex.S = SpinOperators(3,{'1H','1H','15N'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            ex.SOs1H={ex.S.P('x',1)+ex.S.P('x',2),...
                      ex.S.P('y',1)+ex.S.P('y',2),...
                      ex.S.P('z',1)+ex.S.P('z',2)};
            PPM=[0, 0, 170]*1e-6;%chemical shift
            Jij=zeros(3);
            JHH0=-6.8;
            JNHt=-22;
            JNHc=0.4;
            
            Jij(1,2)=JHH0;
            Jij(1,3)=JNHt;Jij(2,3)=JNHc;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
                        
            ex.eH.sel=[1,2];
            ex.eH.all=[1,2];            
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
                        
        case "SABRE-AAX"
            ex.S     = SpinOperators(3,{'1H','1H','15N'})                  ;
            ex.SOs   = {ex.S.P(3,'x'),ex.S.P(3,'y'),ex.S.P(3,'z')}         ;
            PPM      = [0, 0, 100]*1e-6                                    ; % chemical shift
            Jij      = zeros(3)                                            ;
            JHH0     = -8                                                  ;
            JNHt     = -22                                                 ;
            JNHc     = 0                                                   ;
            
            Jij(1,2) = JHH0                                                ;
            Jij(1,3) = JNHt        ;  Jij(2,3) = JNHc                      ;
            Jij      = Jij+Jij'                                            ;%Hz
            
            ex.J     = Jij                                                 ;
            ex.PPM   = PPM                                                 ;
            
            ex.eH    = [1,2]                                               ;
            ex.eC    = [3]                                                 ;
            ex.n1    = 1                                                   ;
            ex.n2    = 2                                                   ;
                                    
        case "Fumarate-spin3"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[4, 4, 170]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=15.9;
            Jij(1,3)=5.8;Jij(2,3)=3.3;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;
            
        case "Maleate-spin3"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P('x',3),ex.S.P('y',3),ex.S.P('z',3)};
            PPM=[4, 4, 170]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=12.3;
            Jij(1,3)=12.9;Jij(2,3)=2.5;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];
            ex.eC=[3];
            ex.n1=1;
            ex.n2=2;    
            
        case "Eth-Phe-Prop-spin2"
            ex.S = SpinOperators(2,{'1H','1H'});
            ex.SOs={ex.S.P('X',1),ex.S.P('X',2),ex.S.P('Y',1),ex.S.P('Y',2)};
            PPM=[7.0028, 5.9778]*1e-6;%chemical shift
            Jij=zeros(2);
            Jij(1,2)=12.73;            
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];            
            ex.n1=1;
            ex.n2=2;
            
        case "Eth-Phe-Prop-spin3"
            ex.S = SpinOperators(3,{'1H','1H','1H'});
            ex.SOs={ex.S.P('z',1),ex.S.P('z',2)};
            PPM=[7.0028, 5.9778, 8]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=12.73;            
            Jij(1,3)=2;Jij(2,3)=0;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3];            
            ex.n1=1;
            ex.n2=2;
        case "AX"
            ex.S = SpinOperators(2,{'1H','13C'});           
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(1,'z'),ex.S.P(2,'z')};
            PPM=[1, 0]*1e-6;%chemical shift
            JAX=varargin{1};
            rAX=4; % Angstroem
            Jij=zeros(2);
            Jij(1,2)=JAX;                                    
            Jij=Jij+Jij';%Hz
            
            r=zeros(2);
            r(1,2)=rAX; % A
            r=r+r';

            ex.T1=[2,30];
            ex.tauc=1e-8; % s
            ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];            
            ex.n1=1;
            ex.n2=2;
            
        case "A2X"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(3,'y'),ex.S.P(1,'z'),ex.S.P(2,'z'),ex.S.P(3,'z')};
            ex.SOsStr={"S1x","S2x","S3x","S1y","S2y","S3y","S1z","S2z","S3z"};            
            PPM=[1, 1, 0]*1e-6;%chemical shift
            JAX=varargin{1};
            JAA=20;
            Jij=zeros(3);
            Jij(1,2)=JAA;            
            Jij(1,3)=JAX;Jij(2,3)=JAX;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3];            
            ex.n1=1;
            ex.n2=2;
            
        case "A3X"
            ex.S = SpinOperators(4,{'1H','1H','1H','13C'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(4,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(3,'y'),ex.S.P(4,'y'),ex.S.P(1,'z'),ex.S.P(2,'z'),ex.S.P(3,'z'),ex.S.P(4,'z')};
            
            ex.SOsStr={"S1x","S2x","S3x","S4x","S1y","S2y","S3y","S4y","S1z","S2z","S3z","S4z"};            
            
            PPM=[1, 1, 1, 0]*1e-6;%chemical shift
            
            JAX=varargin{1};
            JAA=20;                       
            Jij=zeros(4);
            Jij(1,2)=JAA;            
            Jij(1,3)=JAA;Jij(2,3)=JAA;
            Jij(1,4)=JAX;Jij(2,4)=JAX;Jij(3,4)=JAX;
            Jij=Jij+Jij';%Hz

            rAA=1.7473; % Angstroem all 3x1.7473 HH
            rAX=200*3.2257; % Angstroem %3x 2.13178 to C2, 2x3.03925 and 3.59849 = avg 3.2257 to C1
            r=zeros(4);
            r(1,2)=rAA; % A
            r(1,3)=rAA; r(2,3)=rAA; % A
            r(1,4)=rAX; r(2,4)=rAX; r(3,4)=rAX; % A
            r=r+r'; %A
            
            ex.tauc=0.5e-11; % s
            ex.T1=[5,5,5,1];

            ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4];            
            ex.n1=1;
            ex.n2=2;
            ex.NX=1;
            ex.enhance_signal={1,1,1,1};

            
        case "A3N"
            ex.S = SpinOperators(4,{'1H','1H','1H','15N'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(4,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(3,'y'),ex.S.P(4,'y'),ex.S.P(1,'z'),ex.S.P(2,'z'),ex.S.P(3,'z'),ex.S.P(4,'z')};
            
            ex.SOsStr={"S1x","S2x","S3x","S4x","S1y","S2y","S3y","S4y","S1z","S2z","S3z","S4z"};            
            
            PPM=[1, 1, 1, 0]*1e-6;%chemical shift
            
            JAX=varargin{1};
            JAA=20;                       
            Jij=zeros(4);
            Jij(1,2)=JAA;            
            Jij(1,3)=JAA;Jij(2,3)=JAA;
            Jij(1,4)=JAX;Jij(2,4)=JAX;Jij(3,4)=JAX;
            Jij=Jij+Jij';%Hz

            rAA=1.7473; % Angstroem all 3x1.7473 HH
            rAX=200*3.2257; % Angstroem %3x 2.13178 to C2, 2x3.03925 and 3.59849 = avg 3.2257 to C1
            r=zeros(4);
            r(1,2)=rAA; % A
            r(1,3)=rAA; r(2,3)=rAA; % A
            r(1,4)=rAX; r(2,4)=rAX; r(3,4)=rAX; % A
            r=r+r'; %A
            
            ex.tauc=0.5e-11; % s
            ex.T1=[5,5,5,1];

            ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4];            
            ex.n1=1;
            ex.n2=2;
            ex.NX=1;
            ex.enhance_signal={1,1,1,1};


        case "HH-1C-Pyruvate"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','1H','13C'});            
            %ex.SOs={ex.S.P(6,'x'),ex.S.P(6,'y'),ex.S.P(6,'z')};
            ex.SOs={ex.S.P(1,'z')+ex.S.P(2,'z'),ex.S.P(3,'z')+ex.S.P(4,'z')+ex.S.P(5,'z'),ex.S.P(6,'z')};
            ex.SOsStr={"S1z+S2z","S3z+S4z+S5z","S6z"};
            
            PPM=[-27.2, -29.1, 2, 2, 2, 0]*1e-6;%chemical shift
            JAX=1.25;      
            JAA=20;
            JHH=-10.48;
            JaC=0.02;
            JbC=0.55;
            rAA=1.7473; % Angstroem all 3x1.7473 HH
            rAX=3.2257; % Angstroem %3x 2.13178 to C2, 2x3.03925 and 3.59849 = avg 3.2257 to C1
            
            Jij=zeros(6);
            Jij(1,2)=JHH;            
            Jij(1,3)=000;Jij(2,3)=000;
            Jij(1,4)=000;Jij(2,4)=000;Jij(3,4)=JAA;
            Jij(1,5)=000;Jij(2,5)=000;Jij(3,5)=JAA;Jij(4,5)=JAA;
            Jij(1,6)=JaC;Jij(2,6)=JbC;Jij(3,6)=JAX;Jij(4,6)=JAX;Jij(5,6)=JAX;

            Jij=Jij+Jij';%Hz
            r=zeros(4);
            r(1,2)=rAA; % A
            r(1,3)=rAA; r(2,3)=rAA; % A
            r(1,4)=rAX; r(2,4)=rAX; r(3,4)=rAX; % A
            r=r+r'; %A
            
            ex.tauc=0.5e-11; % s
            ex.T1=[1,1,10,10,10,60];

            ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5];            
            ex.n1=1;
            ex.n2=2;


        case "HH-2C-Pyruvate"
            ex.S = SpinOperators(6,{'1H','1H','1H','1H','1H','13C'});            
            ex.SOs={ex.S.P(1,'z')+ex.S.P(2,'z'),ex.S.P(3,'z')+ex.S.P(4,'z')+ex.S.P(5,'z'),ex.S.P(6,'z')};
            ex.SOsStr={"S1z+S2z","S3z+S4z+S5z","S6z"};
            
            PPM=[-27.2, -29.1, 2, 2, 2, 0]*1e-6;%chemical shift
            JAX=-6;      
            JAA=20;
            JHH=-10.48;
            JaC=0.93;
            JbC=0;
            rAA=1.7473; % Angstroem all 3x1.7473 HH
            rAX=3.2257; % Angstroem %3x 2.13178 to C2, 2x3.03925 and 3.59849 = avg 3.2257 to C1
            
            Jij=zeros(6);
            Jij(1,2)=JHH;            
            Jij(1,3)=000;Jij(2,3)=000;
            Jij(1,4)=000;Jij(2,4)=000;Jij(3,4)=JAA;
            Jij(1,5)=000;Jij(2,5)=000;Jij(3,5)=JAA;Jij(4,5)=JAA;
            Jij(1,6)=JaC;Jij(2,6)=JbC;Jij(3,6)=JAX;Jij(4,6)=JAX;Jij(5,6)=JAX;

            Jij=Jij+Jij';%Hz
            r=zeros(4);
            r(1,2)=rAA; % A
            r(1,3)=rAA; r(2,3)=rAA; % A
            r(1,4)=rAX; r(2,4)=rAX; r(3,4)=rAX; % A
            r=r+r'; %A
            
            ex.tauc=0.5e-11; % s
            ex.T1=[1,1,10,10,10,60];

            ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5];            
            ex.n1=1;
            ex.n2=2;
            ex.NX=2;

        case "A(1Hspin1)X"
            ex.S = SpinOperators(2,{'1H-1','13C'});            
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(1,'z'),ex.S.P(2,'z')};
            PPM=[1, 0]*1e-6;%chemical shift
            JAX=varargin{1};
            rAX=4; % Angstroem
            Jij=zeros(2);
            Jij(1,2)=JAX;                                    
            Jij=Jij+Jij';%Hz
            
            r=zeros(2);
            r(1,2)=rAX; % A
            r=r+r';

            ex.T1=[2,30];
            ex.tauc=1e-8; % s
            ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];            
            ex.n1=1;
            ex.n2=2;
     
        case "A(1Hspin1.5)X"
            ex.S = SpinOperators(2,{'1H-3/2','13C'});            
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(1,'z'),ex.S.P(2,'z')};
            PPM=[1, 0]*1e-6;%chemical shift
            JAX=varargin{1};
            rAX=4; % Angstroem
            Jij=zeros(2);
            Jij(1,2)=JAX;                                    
            Jij=Jij+Jij';%Hz
            
            r=zeros(2);
            r(1,2)=rAX; % A
            r=r+r';

            ex.T1=[2,30];
            ex.tauc=1e-8; % s
            ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];            
            ex.n1=1;
            ex.n2=2;   

    case "A3XX"
            ex.S = SpinOperators(5,{'1H','1H','1H','13C','13C'});
            %ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(4,'x')};
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(4,'x'),ex.S.P(5,'x'),...
                    ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(3,'y'),ex.S.P(4,'y'),ex.S.P(5,'y'),...
                    ex.S.P(1,'z'),ex.S.P(2,'z'),ex.S.P(3,'z'),ex.S.P(4,'z'),ex.S.P(5,'z')};
            %ex.SOsStr={"S1x","S2x","S3x","S4x","S5x"};
            %ex.SOs={ex.S.P('z',1),ex.S.P('z',2),ex.S.P('z',3),ex.S.P('z',4)};
            %ex.SOsStr={"S1z","S2z","S3z","S4z"};
            
            PPM=[1, 1, 1, 0, 60]*1e-6;%chemical shift
            
            JX1=1.27;
            JX2=-6.1;
            JXX=59.8;
            JAA=20;                       
            Jij=zeros(5);
            Jij(1,2)=JAA;            
            Jij(1,3)=JAA;Jij(2,3)=JAA;
            Jij(1,4)=JX1;Jij(2,4)=JX1;Jij(3,4)=JX1;
            Jij(1,5)=JX2;Jij(2,5)=JX2;Jij(3,5)=JX2;Jij(4,5)=JXX;
            Jij=Jij+Jij';%Hz

            rAA=1.7473; % Angstroem all 3x1.7473 HH
            rAX=200*3.2257; % Angstroem %3x 2.13178 to C2, 2x3.03925 and 3.59849 = avg 3.2257 to C1
            r=zeros(4);
            r(1,2)=rAA; % A
            r(1,3)=rAA; r(2,3)=rAA; % A
            r(1,4)=rAX; r(2,4)=rAX; r(3,4)=rAX; % A
            r=r+r'; %A
            
            ex.tauc=0.5e-11; % s
            ex.T1=[5,5,5,1];

            ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4];            
            ex.n1=1;
            ex.n2=2;
            ex.NX=2;
    case "TIFBU"
            ex.S = SpinOperators(3,{'1H','1H','13C'});
            ex.SOs={ex.S.P(3,'x'),ex.S.P(3,'y'),ex.S.P(3,'z')};
            PPM=[4.037, 1.178, 174]*1e-6;%chemical shift
            Jij=zeros(3);
            Jij(1,2)=12.5;
            Jij(1,3)=8.4;Jij(2,3)=0.8;
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];
            ex.eC=3;
            ex.n1=1;
            ex.n2=2;

    case "Pyridine"
            ex.S = SpinOperators(5,{'1H','1H','1H','1H','1H'});            
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(4,'x'),ex.S.P(5,'x'),...
                    ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(3,'y'),ex.S.P(4,'y'),ex.S.P(5,'y'),...
                    ex.S.P(1,'z'),ex.S.P(2,'z'),ex.S.P(3,'z'),ex.S.P(4,'z'),ex.S.P(5,'z')};                       
            PPM=[8.55, 8.55, 7.45, 7.45, 7.85]*1e-6;%chemical shift
                        
            Jij=zeros(5);
            Jij(1,2)=-0.13;            
            Jij(1,3)= 4.86;Jij(2,3)=0.98;
            Jij(1,4)= 0.98;Jij(2,4)=4.86;Jij(3,4)=1.36;
            Jij(1,5)= 1.85;Jij(2,5)=1.85;Jij(3,5)=7.66;Jij(4,5)=7.66;
            Jij=Jij+Jij';%Hz

            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2 3 4 5];            
            %ex.n1=1;
            %ex.n2=2;
            ex.NX=0;


    case "3FPy"
            ex.S = SpinOperators(5,{'1H','1H','1H','1H','19F'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(4,'x'),ex.S.P(5,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(3,'y'),ex.S.P(4,'y'),ex.S.P(5,'y'),ex.S.P(1,'z'),ex.S.P(2,'z'),ex.S.P(3,'z'),ex.S.P(4,'z'),ex.S.P(5,'z')};
            
            ex.SOsStr={"S1x","S2x","S3x","S4x","S5x","S1y","S2y","S3y","S4y","S5y","S1z","S2z","S3z","S4z","S5z"};            
            
            PPM=[8.47, 7.65, 7.49, 8.40, 0]*1e-6;%chemical shift
                                   
            Jij=zeros(5);
            Jij(1,2)=2.8;            
            Jij(1,3)=0.7;Jij(2,3)=8.6 ;
            Jij(1,4)=000;Jij(2,4)=1.2 ;Jij(3,4)=4.6;
            Jij(1,5)=001;Jij(2,5)=8.75;Jij(3,5)=4.9;Jij(4,5)=1.7;
            Jij=Jij+Jij';%Hz

            %rAA=1.7473; % Angstroem all 3x1.7473 HH
            %rAX=200*3.2257; % Angstroem %3x 2.13178 to C2, 2x3.03925 and 3.59849 = avg 3.2257 to C1
            %r=zeros(4);
            %r(1,2)=rAA; % A
            %r(1,3)=rAA; r(2,3)=rAA; % A
            %r(1,4)=rAX; r(2,4)=rAX; r(3,4)=rAX; % A
            %r=r+r'; %A
            
            ex.tauc=0.5e-11; % s
            ex.T1=[5,5,5,1];

            %ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            %ex.eH=[1 2 3 4];            
            %ex.n1=1;
            %ex.n2=2;
            ex.NX=1; % number of X nuclei

        case "35FPy"
            ex.S = SpinOperators(5,{'1H','1H','1H','19F','19F'});
            ex.SOs={ex.S.P(1,'x'),ex.S.P(2,'x'),ex.S.P(3,'x'),ex.S.P(4,'x'),ex.S.P(5,'x'),ex.S.P(1,'y'),ex.S.P(2,'y'),ex.S.P(3,'y'),ex.S.P(4,'y'),ex.S.P(5,'y'),ex.S.P(1,'z'),ex.S.P(2,'z'),ex.S.P(3,'z'),ex.S.P(4,'z'),ex.S.P(5,'z')};
            
            ex.SOsStr={"S1x","S2x","S3x","S4x","S5x","S1y","S2y","S3y","S4y","S5y","S1z","S2z","S3z","S4z","S5z"};            
            
            PPM=[8.47, 7.65, 7.49, 8.40, 0]*1e-6;%chemical shift
                                   
            Jij=zeros(5);
            Jij(1,2)=2.8;            
            Jij(1,3)=0.7;Jij(2,3)=8.6 ;
            Jij(1,4)=000;Jij(2,4)=1.2 ;Jij(3,4)=4.6;
            Jij(1,5)=001;Jij(2,5)=8.75;Jij(3,5)=4.9;Jij(4,5)=1.7;
            Jij=Jij+Jij';%Hz

            %rAA=1.7473; % Angstroem all 3x1.7473 HH
            %rAX=200*3.2257; % Angstroem %3x 2.13178 to C2, 2x3.03925 and 3.59849 = avg 3.2257 to C1
            %r=zeros(4);
            %r(1,2)=rAA; % A
            %r(1,3)=rAA; r(2,3)=rAA; % A
            %r(1,4)=rAX; r(2,4)=rAX; r(3,4)=rAX; % A
            %r=r+r'; %A
            
            ex.tauc=0.5e-11; % s
            ex.T1=[5,5,5,1];

            %ex.r=r;
            ex.J=Jij;
            ex.PPM=PPM;
            %ex.eH=[1 2 3 4];            
            %ex.n1=1;
            %ex.n2=2;
            ex.NX=1; % number of X nuclei


    case "ABX"
            a=[1,0;0,0];
            b=[0,0;0,1];
            
            ex.S2 = SpinOperators(2,{'1H','1H'});
            ex.S = SpinOperators(3,{'1H','1H','13C'});

            Tp=ex.S2.U+1/2*(ex.S2.z{1}+ex.S2.z{2})+ex.S2.z{1}*ex.S2.z{2};

            ex.SOs={ex.S.P(3,'x'),ex.S.P(3,'y'),ex.S.P(3,'z'),...
                2*(ex.S.U-ex.S.SSnorm(1,2)),...
                kron((ex.S2.U-ex.S2.SSnorm(1,2)),a),...
                kron((ex.S2.U-ex.S2.SSnorm(1,2)),b),...
                kron(Tp,b)};
            ex.SOsStr={"3X","3Y","3Z","S","Sa","Sb", "T+b"};
            
            d1=4.27;
            d2=1.32;            
            PPM=[d1,d2,174]*1e-6;%chemical shift
            J12=7.1;
            J13=3.0;
            J23=0;                        
            Jij=zeros(3);
            Jij(1,2)=J12;
            Jij(1,3)=J13;Jij(2,3)=J23;                        
            Jij=Jij+Jij';%Hz
            
            ex.J=Jij;
            ex.PPM=PPM;
            ex.eH=[1 2];
            ex.eC=[3]; 
            ex.n1=1;
            ex.n2=2;

        otherwise
            error("such system is not defined (yet)")
    end
end

