function Yout = SABRE_SEPPINEPT_SOT(ex)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% nonpolorized initial spin state of the Ir-complex and substrate %%%%
    rC0          =  DensityMatrix(ex.Sc.U)                                 ;
    rS0          =  DensityMatrix(ex.Ss.U)                                 ;
            
    NS2          =  ex.Ss.Nstates^2                                        ;
    NC2          =  ex.Sc.Nstates^2                                        ;  
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% relaxation superoperator of the Ir-complex and substrate%%%%%%%%%%%%
    RsC          = RLFF_EN(ex.Sc,ex.T1C)                                   ;
    RsS          = RLFF_EN(ex.Ss,ex.T1S)                                   ;
    %% Yout matrix %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Zero         = zeros(length(ex.t1v),1)                                 ; 
    Yout.c       = cell(length(ex.SOc),1)                                  ;
    Yout.s       = cell(length(ex.SOs),1)                                  ;
    for ik       = 1:length(ex.SOc)                    
        Yout.c{ik} = Zero                                                  ;                    
    end
    for ik      = 1:length(ex.SOs)                    
        Yout.s{ik} = Zero                                                  ;
    end    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate SABRE experiment %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%         
    HsB         = 2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,ex.B0,"full")             ;
    HcB         = 2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,ex.B0,"full")             ;   
    
    SABRE       = SABRE_MOD2_matrix(rC0,...
                  ex.Ss,HsB,RsS,...
                  ex.Sc,HcB,RsC,...
                  ex.Sh,...
                  ex.fpH,ex.Wa,ex.Kd)                                      ;
    Yout.SABRE  = SABRE                                                    ;
    % initial state
    
    [rS0,rC0]   = SABRE_kinetic(rS0,rC0,SABRE,NS2,NC2,ex.prebubble)        ; 
       print_progress(0)                                                   ;
    for ii     = 1:length(ex.t1v)
        print_progress((ii-0)/length(ex.t1v))                              ;
        tau     = ex.t1v(ii)                                               ;            
        
        %SOT
        % First pulse Selective pulse 90x on the second H (-29 ppm)
        rS      = rS0                                                      ;
        rC      = rC0.RotationSuperOperator(pi/2,'X',ex.Sc,ex.eH2C)        ; 
        
        [rS,rC] = SABRE_kinetic(rS,rC,SABRE,NS2,NC2,ex.tau1)               ;
        
        % Second pulse selective pulse 180x on both H 
        rC      = rC.RotationSuperOperator(pi,'X',ex.Sc,[ex.eH1C ex.eH2C]) ;
     
        [rS,rC] = SABRE_kinetic(rS,rC,SABRE,NS2,NC2,ex.tau1)               ;
         
        % Delay before the Third pulse 
        
        [rS,rC] = SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau)                   ;
         
        % Third pulse selective 180x on the second H and 180x for C     
        
        rC     = rC.RotationSuperOperator(pi,'X',ex.Sc,ex.eH2C)            ;
        rC     = rC.RotationSuperOperator(pi,'X',ex.Sc,ex.eCC)             ;
        rS     = rS.RotationSuperOperator(pi,'X',ex.Ss,ex.eCS)             ;
       
        [rS,rC] = SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau)                   ;
        
        % Fourth pulse selective 180x on the second H and 180x for C     
        
        rC     = rC.RotationSuperOperator(pi/2,'X',ex.Sc,ex.eH2C)          ;
        rC     = rC.RotationSuperOperator(pi/2,'X',ex.Sc,ex.eCC)           ;
        rS     = rS.RotationSuperOperator(pi/2,'X',ex.Ss,ex.eCS)           ;
       

        Yts    = real(Amplitudes(rS,ex.SOs))                               ;                                
        Ytc    = real(Amplitudes(rC,ex.SOc))                               ;
        for ik = 1:length(ex.SOc)                    
            Yout.c{ik}(ii) = real(Ytc(ik))                                 ;
        end
        for ik = 1:length(ex.SOs)                    
            Yout.s{ik}(ii) = real(Yts(ik))                                 ;
        end
    end
        Yout.rC = rC                                                       ;
        Yout.rS = rS                                                       ;
end

function [rS,rC] = SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau)
    
         vecS    = mtz2vec(rS.val)/trace(rS.val)*SABRE.fs                  ;
         vecC    = mtz2vec(rC.val)/trace(rC.val)*SABRE.fc                  ;
         vec     = [vecS' vecC']'                                          ;
         
         vec     = (expm(SABRE.A*tau))*vec                                 ;
         
         rS.val  = vec2mtz(vec(1:NS2))/SABRE.fs                            ;
         rC.val  = vec2mtz(vec(NS2+1:NS2+NC2))/SABRE.fc                    ;
end
  