function [spec] = SABRE_mod2_FID(ex,rS0,rC0,spec)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    rC=rC0; rS=rS0; % it is to initiate temporary density matrices. 
    %% initial spin state of the Ir-complex and substrate  
    if ~isempty(spec.Excitation.C)
        rC0=rC0.RotationSuperOperator(spec.pulse,spec.ph1,ex.Sc,spec.Excitation.C);
    end
    
    if ~isempty(spec.Excitation.S)
        rS0=rS0.RotationSuperOperator(spec.pulse,spec.ph1,ex.Ss,spec.Excitation.S);
    end
                   
    NS2=ex.Ss.Nstates^2;
    NC2=ex.Sc.Nstates^2;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% relaxation superoperator of the Ir-complex and substrate
    RsC=RLFF_EN(ex.Sc,ex.T1C);
    RsS=RLFF_EN(ex.Ss,ex.T1S);    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate SABRE FID
    B=spec.B0;
    % delay 
    HsB=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,B,"full");
    HcB=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,B,"full");
    SABRE=SABRE_MOD2_matrix(rC0,...
                            ex.Ss,HsB,RsS,...
                            ex.Sc,HcB,RsC,...
                            ex.Sh,...
                            ex.fpH,ex.Wa,ex.Kd);
    spec.Yts=zeros(spec.TD,length(ex.SOsFID));
    spec.Ytc=zeros(spec.TD,length(ex.SOcFID));
    spec.DTime = 1 / spec.SW; % [Hz]
    spec.AQTime= (0:1:spec.TD-1)'*spec.DTime;    
    vecS0=mtz2vec(rS0.val)/trace(rS0.val)*SABRE.fs;
    vecC0=mtz2vec(rC0.val)/trace(rC0.val)*SABRE.fc;
    vec0=[vecS0' vecC0']';        
    for it=1:spec.TD
        if mod(it,100)==0
            display(it/spec.TD*100);
        end
        t=spec.AQTime(it); % current time
        vec=expm(SABRE.A*t)*vec0; 
        rS.val=vec2mtz(vec(1:NS2))/SABRE.fs;
        rC.val=vec2mtz(vec(NS2+1:NS2+NC2))/SABRE.fc;
        spec.Yts(it,:)=(Amplitudes(rS,ex.SOsFID));
        spec.Ytc(it,:)=(Amplitudes(rC,ex.SOcFID));
    end
    %% FID
    spec.FIDc_spins=(spec.Ytc(:,1:ex.Sc.N)) * SABRE.fc;    
    spec.FIDs_spins=(spec.Yts(:,1:ex.Ss.N)) * SABRE.fs;
    spec.FIDc = sum(spec.FIDc_spins,2);
    spec.FIDs = sum(spec.FIDs_spins,2);    
    spec.FID =  spec.FIDs + spec.FIDc ;
    %ex.Sc.SpinName=="1H"
    %spec.FID_1H = (spec.Ytc(:,1:2) + 1i*spec.Ytc(:,ex.Sc.N+1:ex.Sc.N+1+2)) * SABRE.fc;
    %spec.FID_1H = sum(spec.FID_1H,2);
    spec.FID_15N = (spec.Ytc(:,3:end)) * SABRE.fc;
    spec.FID_15N = sum(spec.FID_15N,2) + spec.FIDs;
    %% spectrum
    spec.spec = fftshift(fft(spec.FID),1); %FFT in indirect dimension
    spec.spec_c = fftshift(fft(spec.FIDc),1); %FFT in indirect dimension
    spec.spec_s = fftshift(fft(spec.FIDs),1); %FFT in indirect dimension
    %spec.spec_1H = fftshift(fft(spec.FID_1H),1); %FFT in indirect dimension
    spec.spec_15N = fftshift(fft(spec.FID_15N),1); %FFT in indirect dimension
    spec.FRQ = linspace(-spec.SW/2,spec.SW/2,spec.TD); %indirect frequency domain
end

