function Yout = pulsed_sabre_tdBd(ex)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% nonpolorized initial spin state of the Ir-complex and substrate
    rC0=DensityMatrix(ex.Sc.U);
    rS0=DensityMatrix(ex.Ss.U);
    rS=rS0;
    rC=rC0;
            
    NS2=ex.Ss.Nstates^2;
    NC2=ex.Sc.Nstates^2;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% relaxation superoperator of the Ir-complex and substrate
    RsC=RLFF_EN(ex.Sc,ex.T1C);
    RsS=RLFF_EN(ex.Ss,ex.T1S);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Hailtonian in the laboratory frame for the Ir-complex and substrate
    % pulse
    HsBp=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,ex.Bp);
    HcBp=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,ex.Bp);        
    SABREp=SABRE_MOD2_matrix(rC0,...
        ex.Ss,HsBp,RsS,...
        ex.Sc,HcBp,RsC,...
        ex.Sh,...
        ex.fpH,ex.Wa,ex.Kd);
    SAtp=expm(SABREp.A*ex.tp);
    
 

    %% Yout matrix %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Yout=zeros(length(ex.tdv),length(ex.Bdv),ex.rep); %zero matrix for data output
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate SHEATH-SABRE experiment 
    for iBd=1:length(ex.Bdv)
        disp(iBd/length(ex.Bdv)*100);
        Bd=ex.Bdv(iBd);
        % delay 
        HsBd=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,Bd);
        HcBd=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,Bd);
        SABREd=SABRE_MOD2_matrix(rC0,...
            ex.Ss,HsBd,RsS,...
            ex.Sc,HcBd,RsC,...
            ex.Sh,...
            ex.fpH,ex.Wa,ex.Kd);
        
        for itd=1:length(ex.tdv)
            td=ex.tdv(itd);
            SAtd=expm(SABREd.A*td);
            
            vecS0=mtz2vec(rS0.val)/trace(rS0.val)*SABREp.fs;
            vecC0=mtz2vec(rC0.val)/trace(rC0.val)*SABREp.fc;
            vec=[vecS0' vecC0']';
            
            for ir=1:ex.rep               
                vec=SAtd*SAtp*vec; 
                
                rS.val=vec2mtz(vec(1:NS2))/SABREp.fs;
                rC.val=vec2mtz(vec(NS2+1:NS2+NC2))/SABREp.fc;
                
                
                Yts=Amplitudes(rS,ex.SOs);                                
                %Ytc=Amplitudes(rC,ex.SOc);
                Yout(itd,iBd,ir)=real(Yts(3));
            end   
        end
    end
end

