function Yout = pulsed_SABRE_tp(ex)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% nonpolorized initial spin state of the Ir-complex and substrate
    rC0=DensityMatrix(ex.Sc.U);
    rS0=DensityMatrix(ex.Ss.U);
    rS=rS0;
    rC=rC0;
            
    NS2=ex.Ss.Nstates^2;
    NC2=ex.Sc.Nstates^2;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% relaxation superoperator of the Ir-complex and substrate
    RsC=RLFF_EN(ex.Sc,ex.T1C);
    RsS=RLFF_EN(ex.Ss,ex.T1S);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Hailtonian in the laboratory frame for the Ir-complex and substrate

    HsBd=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,ex.Bd,"full");
    HcBd=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,ex.Bd,"full");     
    % delay  
    SABREd=SABRE_MOD2_matrix(rC0,...
        ex.Ss,HsBd,RsS,...
        ex.Sc,HcBd,RsC,...
        ex.Sh,...
        ex.fpH,ex.Wa,ex.Kd);
    SAtd=expm(SABREd.A*ex.td);
    
    %% Yout matrix %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Yout=zeros(length(ex.tpv),ex.rep); %zero matrix for data output
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate SHEATH-SABRE experiment 
        
    Bp=ex.Bpv;
    % pulse
    HsBp=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,Bp,"full");
    HcBp=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,Bp,"full"); 
    SABREp=SABRE_MOD2_matrix(rC0,...
        ex.Ss,HsBp,RsS,...
        ex.Sc,HcBp,RsC,...
        ex.Sh,...
        ex.fpH,ex.Wa,ex.Kd);
    
    %print_progress(0);
    for itp=1:length(ex.tpv)                    
        %print_progress(itp/length(ex.tpv))
                                
        tp=ex.tpv(itp);
        SAtp=expm(SABREp.A*tp);

        vecS0=mtz2vec(rS0.val)/trace(rS0.val)*SABREp.fs;
        vecC0=mtz2vec(rC0.val)/trace(rC0.val)*SABREp.fc;
        vec=[vecS0' vecC0']';

        for ir=1:ex.rep               
            vec=SAtd*SAtp*vec; 

            rS.val=vec2mtz(vec(1:NS2))/SABREp.fs;
            rC.val=vec2mtz(vec(NS2+1:NS2+NC2))/SABREp.fc;

            Yts=Amplitudes(rS,ex.SOs);                                
            %Ytc=Amplitudes(rC,ex.SOc);
            Yout(itp,ir)=real(Yts(1));
        end   
    end    
end

