function Yout = sabre_Esotheric_SOT(ex)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% nonpolorized initial spin state of the Ir-complex and substrate
    rC0=DensityMatrix(ex.Sc.U);
    rS0=DensityMatrix(ex.Ss.U);
            
    NS2=ex.Ss.Nstates^2;
    NC2=ex.Sc.Nstates^2;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% relaxation superoperator of the Ir-complex and substrate
    RsC=RLFF_EN(ex.Sc,ex.T1C);
    RsS=RLFF_EN(ex.Ss,ex.T1S);
    %% Yout matrix %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Zero=zeros(length(ex.t1v),1); 
    Yout.c=cell(length(ex.SOc),1);
    Yout.s=cell(length(ex.SOs),1);
    for ik = 1:length(ex.SOc)                    
        Yout.c{ik}=Zero;                    
    end
    for ik = 1:length(ex.SOs)                    
        Yout.s{ik}=Zero;
    end    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate SABRE experiment         
    HsB=2*pi*HZJij(ex.Ss,ex.ppmS,ex.JS,ex.B0,"full");
    HcB=2*pi*HZJij(ex.Sc,ex.ppmC,ex.JC,ex.B0,"full");   
    
    SABRE=SABRE_MOD2_matrix(rC0,...
            ex.Ss,HsB,RsS,...
            ex.Sc,HcB,RsC,...
            ex.Sh,...
            ex.fpH,ex.Wa,ex.Kd);
    Yout.SABRE = SABRE;
    % Initial state
    
    [rS0,rC0]=SABRE_kinetic(rS0,rC0,SABRE,NS2,NC2,ex.prebubble); 
    
      for it1=1:length(ex.t1v)  
           it1/length(ex.t1v)*100
           tau1 = ex.t1v(it1);            
          for it2=1:length(ex.t2v)
              it2/length(ex.t2v)*100
              tau2=ex.t2v(it2);   
              
            %SOT
            % First pulse
            rS = rS0;
            rC = rC0.RotationSuperOperator(pi/2,'Y',ex.Sc,ex.eHC);

            [rS,rC]=SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau1);

            % Second pulse 
            rC=rC.RotationSuperOperator(pi,'X',ex.Sc,[ex.eHC ex.eNC]);
            rS=rS.RotationSuperOperator(pi,'X',ex.Ss,ex.eNS);

            [rS,rC]=SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau1);
            
            % Third pulse
            rC = rC.RotationSuperOperator(pi/2,'-Y',ex.Sc,ex.eHC);

            [rS,rC]=SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau2);
            
            % Forth pulse
            rC = rC.RotationSuperOperator(pi,'X',ex.Sc,ex.eHC);

            [rS,rC]=SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau2);
            
            % Fifth pulse       
            rC=rC.RotationSuperOperator(pi/2,'Y',ex.Sc,[ex.eHC ex.eNC]);
            rS=rS.RotationSuperOperator(pi/2,'Y',ex.Ss,ex.eNS);% Y
            
            [rS,rC]=SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau1);

            % sixth pulse 
            rC=rC.RotationSuperOperator(pi,'X',ex.Sc,[ex.eHC ex.eNC]);
            rS=rS.RotationSuperOperator(pi,'X',ex.Ss,ex.eNS);% X

            [rS,rC]=SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau1);

            Yts=real(Amplitudes(rS,ex.SOs));                                
            Ytc=real(Amplitudes(rC,ex.SOc));
            for ik = 1:length(ex.SOc)                    
                Yout.c{ik}(it2, it1)=real(Ytc(ik)); 
            end
            for ik = 1:length(ex.SOs)                    
                Yout.s{ik}(it2, it1)=real(Yts(ik));
            end
         end 
       end
        Yout.rC = rC;
        Yout.rS = rS;
 
end

function [rS,rC]=SABRE_kinetic(rS,rC,SABRE,NS2,NC2,tau)
    
         vecS=mtz2vec(rS.val)/trace(rS.val)*SABRE.fs;
         vecC=mtz2vec(rC.val)/trace(rC.val)*SABRE.fc;
         vec=[vecS' vecC']';
         
         vec=(expm(SABRE.A*tau))*vec;
         
         rS.val=vec2mtz(vec(1:NS2))/SABRE.fs;
         rC.val=vec2mtz(vec(NS2+1:NS2+NC2))/SABRE.fc;
end
  