function [spec] = Spectrum_1D(ex,r0,spec)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    r=r0;
    %% initial spin state of the Ir-complex and substrate  
    if ~isempty(spec.Excitation.Spins)
        r=r0.RotationSuperOperator(spec.Excitation.Pulse,spec.Excitation.Phase,ex.S,spec.Excitation.Spins);
    end
                                  
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% calculate SABRE FID    
    % delay     
    HB=2*pi*HXYZJij(ex.S,ex.PPM,ex.J,spec.B0,"full");        
    %[~,E]=eig(HB/(2*pi));
    %disp(E);
    spec.DTime = 1 / spec.SW; % [Hz]
    spec.AQTime= (0:spec.TD-1)'*spec.DTime;  

    switch spec.Relaxation       
        case "Off"
        [~,A,~]=r.EvolutionConstH(HB,spec.AQTime,ex.SOs);        

        case "DD"
            Rs=RDD_EN(ex.S,ex.r,ex.tauc);
            Ls=-1i*H2Super(HB)+Rs;
            [~,A,~]=r. EvolutionConstL(Ls,spec.AQTime,ex.SOs);
        case "LFF"
            Rs=RLFF_EN(ex.S,ex.T1);
            Ls=-1i*H2Super(HB)+Rs;
            [~,A,~]=r. EvolutionConstL(Ls,spec.AQTime,ex.SOs);
        otherwise 
            error("only Off, DD or LFF")
    end
    spec.Amplitudes=A; 

    %% FID
    spec.FIDx_spins=(spec.Amplitudes(:,         1:1*ex.S.N));        %1:ex.S.N
    spec.FIDy_spins=(spec.Amplitudes(:,  ex.S.N+1:2*ex.S.N));        %1:ex.S.N
    spec.FIDz_spins=(spec.Amplitudes(:,2*ex.S.N+1:3*ex.S.N));        %1:ex.S.N
    spec.FID.x=0;
    spec.FID.y=0;
    spec.FID.z=0;    
    for n=1:ex.S.N
        spec.FID.x = spec.FID.x + spec.FIDx_spins(:,n)*ex.S.g_gh{n};            
        spec.FID.y = spec.FID.y + spec.FIDy_spins(:,n)*ex.S.g_gh{n};            
        spec.FID.z = spec.FID.z + spec.FIDz_spins(:,n)*ex.S.g_gh{n};            
    end
    spec.FID.x = spec.FID.x.*exp(-spec.AQTime*spec.R2);
    spec.FID.y = spec.FID.y.*exp(-spec.AQTime*spec.R2);
    spec.FID.z = spec.FID.z.*exp(-spec.AQTime*spec.R2);
    spec.FID.RX=spec.FID.x*spec.RX(1)+...
                spec.FID.y*spec.RX(2)+...
                spec.FID.z*spec.RX(3);

    %% spectrum
    spec.spec.x = fftshift(fft(spec.FID.x),1); %FFT in indirect dimension            
    spec.spec.y = fftshift(fft(spec.FID.y),1); %FFT in indirect dimension            
    spec.spec.z = fftshift(fft(spec.FID.z),1); %FFT in indirect dimension            
    spec.spec.RX = fftshift(fft(spec.FID.RX),1); %FFT in indirect dimension            
    spec.FRQ = linspace(-spec.SW/2,spec.SW/2,spec.TD)'; %indirect frequency domain
end

