clear all
close all

tic

SW1      = 500                                                             ; % Hz
SW2      = 500                                                             ; % Hz
TD1      = 512                                                             ;
TD2      = 512                                                             ;
DW1      = 1/SW1                                                           ;
DW2      = 1/SW2                                                           ;
AQ1      = (0:TD1-1)*DW1                                                   ;
AQ2      = (0:TD2-1)*DW2                                                   ;
nu1      = 100                                                             ;
nu2      = 200                                                             ;

R        = 4                                                               ; % s-1
w1       = 2*pi*nu1                                                        ;
w2       = 2*pi*nu2                                                        ;


%% 2 signal having the same frequency
S1 = exp((1i*2*pi*nu1)*AQ1).*exp(-R*AQ1)+exp((1i*2*pi*nu2)*AQ2).*exp(-R*AQ2)      ;
S2 = exp((1i*2*pi*nu2)*AQ2).*exp(-R*AQ2)+ exp((1i*2*pi*nu1)*AQ1).*exp(-R*AQ1)     ;


% Signal0 = zeros(TD1, TD2);
% for td=1:TD1
%     Signal0(td,:)=S1(td)*S2;
% end

Signal0 = transpose(S1)*S2                                                 ;
[M,N]   = size(transpose(S1)*S2)                                           ;

figure("color","white",'DefaultAxesFontSize',14)
Spec0   = fft2(Signal0)                                                    ;
s       = surf(real(Spec0))                                                ;
%s      = surf(real(Signal0))                                              ;
% s     = contourf(AQ1,AQ2,abs((Spec0)))                                   ;
view(2)
s.EdgeColor = "none"                                                       ;
grid off
xlim([0 SW1])
ylim([0 SW2])
%% 1D 2 peaks on + and - frequency

Signal_1 = 0.5*(exp(1i*w1*AQ1)+exp(-1i*w1*AQ1)).*exp(-R*AQ1)               ; % section 7.6.1
Spec     = fft(Signal_1)                                                   ;
Spec     = fftshift(Spec)                                                  ;


figure("color","white",'DefaultAxesFontSize',14)
plot (AQ1,Signal_1)
title('FID')


Frq        = SW1*(-TD1/2+1:TD1/2)/TD1                                      ; % frequency domain
figure("color","white",'DefaultAxesFontSize',12)
plot(Frq, [real(Spec);imag(Spec)])
title('Spectrum')
xlabel('Frequency (Hz)')
legend(['real(S(w))';'imag(S(w))'])

%%

Signal_1 = exp(1i*w1*AQ1).*exp(-AQ1*R).*exp(1i*w2*AQ2).*exp(-AQ2*R)        ; 


Signal0 = zeros(TD1, TD2);
for td2 = 1:TD2 
   for td1 = 1:TD1
    Signal0(td2,td1) = exp(1i*w1*AQ1(td1)).*exp(-AQ1(td1)*R).*exp(1i*w2*AQ2(td2)).*exp(-AQ2(td2)*R)        ;                                              
   end
end

Spec     = fft2(Signal0)                                                   ;

%Frq        = SW1*(-TD1/2+1:TD1/2)/TD1                                      ; % frequency domain
figure
s       = surf(real(Spec))    ;   
s.EdgeColor = "none"                                                       ;
grid off
%plot(Frq, [real(Spec);imag(Spec)])
%plot(Frq, [real(Spec);imag(Spec)])
view(3)
title('Spectrum')
xlabel('Frequency (Hz)')
legend(['real(S(w))';'imag(S(w))'])
xlim([0 SW1])
ylim([0 SW2])

%% Ss and Sc %% 7.6.2.2 amplitude modulation

%Signal_1 = cos(1i*w1*AQ1).*exp(-AQ1*R).*exp(1i*w2*AQ2).*exp(-AQ2*R)        ; 
%Signal_2 = sin(1i*w1*AQ1).*exp(-AQ1*R).*exp(1i*w2*AQ2).*exp(-AQ2*R)        ; 

Signal01 = zeros(TD1, TD2)                                                 ;
for td2 = 1:TD2 
   for td1 = 1:TD1
    Signal01(td2,td1) = 0.5*(exp(1i*w1*AQ1(td1))+exp(-1i*w1*AQ1(td1))).*exp(-AQ1(td1)*R).*exp(1i*w2*AQ2(td2)).*exp(-AQ2(td2)*R)        ;                                              
   end
end

Signal02 = zeros(TD1, TD2)                                                 ;
for td2 = 1:TD2 
   for td1 = 1:TD1
    Signal02(td2,td1) = 1/2i*(exp(1i*w1*AQ1(td1))-exp(-1i*w1*AQ1(td1))).*exp(-AQ1(td1)*R).*exp(1i*w2*AQ2(td2)).*exp(-AQ2(td2)*R)        ;                                              
   end
end

% fft
Spec1    = fft(Signal01,TD2,1)                                             ;
Spec2    = fft(Signal02,TD2,1)                                             ;
a        = real(Spec1)                                                     ;
b        = real(Spec2)                                                     ;

Spec11   = fft(a,TD1,2)                                                    ;
Spec22   = fft(b,TD1,2)                                                    ;

Spec     = real(Spec11)-imag(Spec22)                                       ;
      
figure
s        = surf(Spec)                                                      ;   
s.EdgeColor = "none"                                                       ;
grid off
view(1)
title('Spectrum')
xlabel('Frequency (Hz)')
xlim([0 SW1])
ylim([0 SW2])

figure
s        = surf(real(Spec11))                                                ;   
s.EdgeColor = "none"                                                       ;
grid off
view(3)
title('Spectrum')
xlabel('Frequency (Hz)')
xlim([0 SW1])
ylim([0 SW2])

%% States-Haberkorn-Ruben method (SHR)

Signal01 = zeros(TD1, TD2)                                                 ;
for td2 = 1:TD2 
   for td1 = 1:TD1                                             
    Signal01(td2,td1) = cos(w1*AQ1(td1)).*exp(-AQ1(td1)*R).*exp(1i*w2*AQ2(td2)).*exp(-AQ2(td2)*R)        ;                                              
   end
end

Signal02 = zeros(TD1, TD2)                                                 ;
for td2 = 1:TD2 
   for td1 = 1:TD1                                      
    Signal02(td2,td1) =  sin(w1*AQ1(td1)).*exp(-AQ1(td1)*R).*exp(1i*w2*AQ2(td2)).*exp(-AQ2(td2)*R)        ;   
   end
end

% fft
Spec1    = fft(Signal01,TD2,1)                                             ;
Spec2    = fft(Signal02,TD2,1)                                             ;
a        = real(Spec1)                                                     ;
b        = real(Spec2)                                                     ;
 
SHR      = a + 1i*b                                                        ; 

Spec     = fft(SHR,TD1,2)                                                  ;

      
figure
s        = surf(real(Spec))                                                ;   
s.EdgeColor = "none"                                                       ;
grid off
view(3)
title('Spectrum')
xlabel('Frequency (Hz)')
xlim([0 SW1])
ylim([0 SW2])

%% Marion-Wüthrich or TPPI method 

Signal01 = zeros(TD1, TD2)                                                 ;
for td2 = 1:TD2 
   for td1 = 1:TD1    
    Signal01(td2,td1) = cos(w1*AQ1(td1)+ td1*(pi/2)).*exp(-AQ1(td1)*R).*exp(1i*w2*AQ2(td2)).*exp(-AQ2(td2)*R)  ;                                              
   end
end

Signal02 = zeros(TD1, TD2)                                                 ;
for td2 = 1:TD2 
   for td1 = 1:TD1                                      
    Signal02(td2,td1) =  sin(w1*AQ1(td1)).*exp(-AQ1(td1)*R).*exp(1i*w2*AQ2(td2)).*exp(-AQ2(td2)*R)            ;   
   end
end

% fft
Spec10   = fft2(Signal01)                                                  ;

Spec1    = fft(Signal01,TD2,1)                                             ;
Spec2    = fft(Signal02,TD2,1)                                             ;
a        = real(Spec1)                                                     ;
b        = real(Spec2)                                                     ;

SHR      = a + 1i*b                                                        ; 

Spec     = fft(SHR,TD1,2)                                                  ;

      
figure
s        = surf(real(Spec10))                                              ;   
s.EdgeColor = "none"                                                       ;
grid off
view(3)
title('Spectrum')
xlabel('Frequency (Hz)')
xlim([0 SW1])
ylim([0 SW2])

%% Marion-Wüthrich or TPPI method 
f       = 0.2                                                              ; % exchange factor 
Signal01 = zeros(TD1, TD2)                                                 ;
for td2 = 1:TD2 
   for td1 = 1:TD1    
    Signal01(td2,td1) = (1-f)*cos(w1*AQ2(td2))*cos(w1*AQ1(td1))+ f*cos(w2*AQ2(td2))*cos(w1*AQ1(td1))   ;  %).*exp(-AQ2(td2)*R)  ;                                              
   end
end

Signal02 = zeros(TD1, TD2)                                                 ;
for td2 = 1:TD2 
   for td1 = 1:TD1                                      
    Signal02(td2,td1) =  (1-f)*cos(w2*AQ1(td1))*cos(w2*AQ2(td2))+ f*cos(w1*AQ1(td1))*cos(w2*AQ2(td2))   ;   
   end
end

% fft
Spec10   = fft2(Signal01)                                                  ;

Spec1    = fft(Signal01,TD2,1)                                             ;
Spec2    = fft(Signal02,TD2,1)                                             ;
a        = real(Spec1)                                                     ;
b        = real(Spec2)                                                     ;

SHR      = a + 1i*b                                                        ; 

Spec     = fft(SHR,TD1,2)                                                  ;

      
figure
s        = surf(real(Spec10))                                              ;   
s.EdgeColor = "none"                                                       ;
grid off
view(3)
title('Spectrum')
xlabel('Frequency (Hz)')
xlim([0 SW1])
ylim([0 SW2])

toc
